/*
qxgedit - Qt XG Editor.

   Copyright (C) 2005-2025, rncbc aka Rui Nuno Capela. All rights reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 
*/

/********************************************************************************
** Form generated from reading UI file 'qxgeditMainForm.ui'
**
** Created by: Qt User Interface Compiler version 6.8.3
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QXGEDITMAINFORM_H
#define UI_QXGEDITMAINFORM_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMenu>
#include <QtWidgets/QMenuBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolBar>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qxgeditAmpEg.h"
#include "qxgeditCheck.h"
#include "qxgeditCombo.h"
#include "qxgeditDial.h"
#include "qxgeditDrumEg.h"
#include "qxgeditEdit.h"
#include "qxgeditFilter.h"
#include "qxgeditPartEg.h"
#include "qxgeditPitch.h"
#include "qxgeditScale.h"
#include "qxgeditUserEg.h"
#include "qxgeditVibra.h"

QT_BEGIN_NAMESPACE

class Ui_qxgeditMainForm
{
public:
    QAction *fileNewAction;
    QAction *fileOpenAction;
    QAction *fileSaveAction;
    QAction *fileSaveAsAction;
    QAction *fileExitAction;
    QAction *viewMenubarAction;
    QAction *viewStatusbarAction;
    QAction *viewToolbarAction;
    QAction *viewRandomizeAction;
    QAction *viewOptionsAction;
    QAction *helpAboutAction;
    QAction *helpAboutQtAction;
    QWidget *MainCentralWidget;
    QVBoxLayout *vboxLayout;
    QTabWidget *MainTabWidget;
    QWidget *SystemEffectTab;
    QVBoxLayout *vboxLayout1;
    QTabWidget *SystemEffectToolBox;
    QWidget *SYSTEMPage;
    QGridLayout *gridLayout;
    QPushButton *MasterResetButton;
    qxgeditDial *MasterTuneDial;
    qxgeditDial *MasterVolumeDial;
    qxgeditDial *MasterTransposeDial;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;
    QWidget *ReverbPage;
    QGridLayout *gridLayout1;
    QPushButton *ReverbResetButton;
    qxgeditCombo *ReverbTypeCombo;
    QSpacerItem *spacerItem2;
    QSpacerItem *spacerItem3;
    qxgeditDial *ReverbParam1Dial;
    qxgeditDial *ReverbParam2Dial;
    qxgeditDial *ReverbParam3Dial;
    qxgeditDial *ReverbParam4Dial;
    qxgeditDial *ReverbParam5Dial;
    qxgeditDial *ReverbParam6Dial;
    qxgeditDial *ReverbParam7Dial;
    qxgeditDial *ReverbParam8Dial;
    qxgeditDial *ReverbParam9Dial;
    qxgeditDial *ReverbParam10Dial;
    qxgeditDial *ReverbReturnDial;
    qxgeditDial *ReverbPanDial;
    qxgeditDial *ReverbParam11Dial;
    qxgeditDial *ReverbParam12Dial;
    qxgeditDial *ReverbParam13Dial;
    qxgeditDial *ReverbParam14Dial;
    qxgeditDial *ReverbParam15Dial;
    qxgeditDial *ReverbParam16Dial;
    QSpacerItem *spacerItem4;
    QWidget *ChorusPage;
    QGridLayout *gridLayout2;
    QPushButton *ChorusResetButton;
    qxgeditCombo *ChorusTypeCombo;
    QSpacerItem *spacerItem5;
    QSpacerItem *spacerItem6;
    qxgeditDial *ChorusParam1Dial;
    qxgeditDial *ChorusParam2Dial;
    qxgeditDial *ChorusParam3Dial;
    qxgeditDial *ChorusParam4Dial;
    qxgeditDial *ChorusParam5Dial;
    qxgeditDial *ChorusParam6Dial;
    qxgeditDial *ChorusParam7Dial;
    qxgeditDial *ChorusParam8Dial;
    qxgeditDial *ChorusParam9Dial;
    qxgeditDial *ChorusParam10Dial;
    qxgeditDial *ChorusReturnDial;
    qxgeditDial *ChorusPanDial;
    qxgeditDial *ChorusReverbDial;
    qxgeditDial *ChorusParam11Dial;
    qxgeditDial *ChorusParam12Dial;
    qxgeditDial *ChorusParam13Dial;
    qxgeditDial *ChorusParam14Dial;
    qxgeditDial *ChorusParam15Dial;
    qxgeditDial *ChorusParam16Dial;
    QSpacerItem *spacerItem7;
    QWidget *VariationPage;
    QGridLayout *gridLayout3;
    QPushButton *VariationResetButton;
    qxgeditCombo *VariationTypeCombo;
    QSpacerItem *spacerItem8;
    QSpacerItem *spacerItem9;
    qxgeditDial *VariationParam1Dial;
    qxgeditDial *VariationParam2Dial;
    qxgeditDial *VariationParam3Dial;
    qxgeditDial *VariationParam4Dial;
    qxgeditDial *VariationParam5Dial;
    qxgeditDial *VariationParam6Dial;
    qxgeditDial *VariationParam7Dial;
    qxgeditDial *VariationParam8Dial;
    qxgeditDial *VariationParam9Dial;
    qxgeditDial *VariationParam10Dial;
    qxgeditDial *VariationReturnDial;
    qxgeditDial *VariationPanDial;
    qxgeditDial *VariationReverbDial;
    qxgeditDial *VariationChorusDial;
    qxgeditDial *VariationConnectDial;
    qxgeditDial *VariationPartDial;
    qxgeditDial *VariationWheelDial;
    qxgeditDial *VariationBendDial;
    qxgeditDial *VariationCATDial;
    qxgeditDial *VariationAC1Dial;
    qxgeditDial *VariationAC2Dial;
    qxgeditDial *VariationParam11Dial;
    qxgeditDial *VariationParam12Dial;
    qxgeditDial *VariationParam13Dial;
    qxgeditDial *VariationParam14Dial;
    qxgeditDial *VariationParam15Dial;
    qxgeditDial *VariationParam16Dial;
    QSpacerItem *spacerItem10;
    QWidget *MultipartTab;
    QVBoxLayout *vboxLayout2;
    QHBoxLayout *hboxLayout;
    QPushButton *MultipartResetButton;
    QComboBox *MultipartCombo;
    QComboBox *MultipartVoiceCombo;
    QSpacerItem *spacerItem11;
    QTabWidget *MultipartToolBox;
    QWidget *MultipartMainPage;
    QGridLayout *gridLayout4;
    QGroupBox *MultipartPartBox;
    QGridLayout *gridLayout5;
    qxgeditDial *MultipartChannelDial;
    qxgeditDial *MultipartElementDial;
    QGroupBox *MultipartVoiceBox;
    QGridLayout *gridLayout6;
    qxgeditDial *MultipartBankMSBDial;
    qxgeditDial *MultipartBankLSBDial;
    qxgeditDial *MultipartProgramDial;
    QGroupBox *MultipartModeBox;
    QGridLayout *gridLayout7;
    qxgeditDial *MultipartPolyModeDial;
    qxgeditDial *MultipartKeyAssignDial;
    qxgeditDial *MultipartPartModeDial;
    QGroupBox *MultipartControlBox;
    QGridLayout *gridLayout8;
    qxgeditDial *MultipartVolumeDial;
    qxgeditDial *MultipartPanDial;
    QGroupBox *MultipartPortamentoBox;
    QGridLayout *gridLayout9;
    qxgeditDial *MultipartPortamentoDial;
    qxgeditDial *MultipartPortaTimeDial;
    QGroupBox *MultipartNoteBox;
    QGridLayout *gridLayout10;
    qxgeditDial *MultipartNoteLowDial;
    qxgeditDial *MultipartNoteHighDial;
    qxgeditDial *MultipartNoteShiftDial;
    qxgeditDial *MultipartDetuneDial;
    QGroupBox *MultipartVelocityBox;
    QGridLayout *gridLayout11;
    qxgeditDial *MultipartVelDepthDial;
    qxgeditDial *MultipartVelOffsetDial;
    qxgeditDial *MultipartVelLowDial;
    qxgeditDial *MultipartVelHighDial;
    QGroupBox *MultipartEffectBox;
    QGridLayout *gridLayout12;
    qxgeditDial *MultipartDryWetDial;
    qxgeditDial *MultipartChorusDial;
    qxgeditDial *MultipartReverbDial;
    qxgeditDial *MultipartVariationDial;
    QSpacerItem *spacerItem12;
    QWidget *MultipartTonePage;
    QGridLayout *gridLayout13;
    QGroupBox *MultipartVibratoBox;
    QGridLayout *gridLayout14;
    qxgeditVibra *MultipartVibra;
    qxgeditDial *MultipartRateDial;
    qxgeditDial *MultipartDepthDial;
    qxgeditDial *MultipartDelayDial;
    QSpacerItem *spacerItem13;
    QGroupBox *MultipartFilterBox;
    QGridLayout *gridLayout15;
    qxgeditFilter *MultipartFilter;
    qxgeditDial *MultipartCutoffDial;
    qxgeditDial *MultipartResonanceDial;
    QSpacerItem *spacerItem14;
    QGroupBox *MultipartAmpEgBox;
    QGridLayout *gridLayout16;
    qxgeditPartEg *MultipartAmpEg;
    qxgeditDial *MultipartAttackDial;
    qxgeditDial *MultipartDecayDial;
    qxgeditDial *MultipartReleaseDial;
    QSpacerItem *spacerItem15;
    QGroupBox *MultipartPitchEgBox;
    QGridLayout *gridLayout17;
    qxgeditPitch *MultipartPitch;
    qxgeditDial *MultipartAttackLevelDial;
    qxgeditDial *MultipartAttackTimeDial;
    qxgeditDial *MultipartReleaseLevelDial;
    qxgeditDial *MultipartReleaseTimeDial;
    QSpacerItem *spacerItem16;
    QSpacerItem *spacerItem17;
    QWidget *MultipartControlPage;
    QGridLayout *gridLayout18;
    QGroupBox *MultipartWheelBox;
    QGridLayout *gridLayout19;
    qxgeditDial *MultipartWheelPitchDial;
    qxgeditDial *MultipartWheelFilterDial;
    qxgeditDial *MultipartWheelAmplDial;
    qxgeditDial *MultipartWheelLFOPmodDial;
    qxgeditDial *MultipartWheelLFOFmodDial;
    qxgeditDial *MultipartWheelLFOAmodDial;
    QGroupBox *MultipartBendBox;
    QGridLayout *gridLayout20;
    qxgeditDial *MultipartBendPitchDial;
    qxgeditDial *MultipartBendFilterDial;
    qxgeditDial *MultipartBendAmplDial;
    qxgeditDial *MultipartBendLFOPmodDial;
    qxgeditDial *MultipartBendLFOFmodDial;
    qxgeditDial *MultipartBendLFOAmodDial;
    QGroupBox *MultipartCATBox;
    QGridLayout *gridLayout21;
    qxgeditDial *MultipartCATPitchDial;
    qxgeditDial *MultipartCATFilterDial;
    qxgeditDial *MultipartCATAmplDial;
    qxgeditDial *MultipartCATLFOPmodDial;
    qxgeditDial *MultipartCATLFOFmodDial;
    qxgeditDial *MultipartCATLFOAmodDial;
    QGroupBox *MultipartPATBox;
    QGridLayout *gridLayout22;
    qxgeditDial *MultipartPATPitchDial;
    qxgeditDial *MultipartPATFilterDial;
    qxgeditDial *MultipartPATAmplDial;
    qxgeditDial *MultipartPATLFOPmodDial;
    qxgeditDial *MultipartPATLFOFmodDial;
    qxgeditDial *MultipartPATLFOAmodDial;
    QGroupBox *MultipartTuningBox;
    QGridLayout *gridLayout23;
    qxgeditDial *MultipartTuningC_Dial;
    qxgeditDial *MultipartTuningCsDial;
    qxgeditDial *MultipartTuningD_Dial;
    qxgeditDial *MultipartTuningDsDial;
    qxgeditDial *MultipartTuningE_Dial;
    qxgeditDial *MultipartTuningF_Dial;
    qxgeditDial *MultipartTuningFsDial;
    qxgeditDial *MultipartTuningG_Dial;
    qxgeditDial *MultipartTuningGsDial;
    qxgeditDial *MultipartTuningA_Dial;
    qxgeditDial *MultipartTuningAsDial;
    qxgeditDial *MultipartTuningB_Dial;
    QSpacerItem *spacerItem18;
    QWidget *MultipartOptionsPage;
    QGridLayout *gridLayout24;
    QGroupBox *MultipartAC1Box;
    QGridLayout *gridLayout25;
    qxgeditDial *MultipartAC1ControlDial;
    qxgeditDial *MultipartAC1PitchDial;
    qxgeditDial *MultipartAC1FilterDial;
    qxgeditDial *MultipartAC1AmplDial;
    qxgeditDial *MultipartAC1LFOPmodDial;
    qxgeditDial *MultipartAC1LFOFmodDial;
    qxgeditDial *MultipartAC1LFOAmodDial;
    QGroupBox *MultipartAC2Box;
    QGridLayout *gridLayout26;
    qxgeditDial *MultipartAC2ControlDial;
    qxgeditDial *MultipartAC2PitchDial;
    qxgeditDial *MultipartAC2FilterDial;
    qxgeditDial *MultipartAC2AmplDial;
    qxgeditDial *MultipartAC2LFOPmodDial;
    qxgeditDial *MultipartAC2LFOFmodDial;
    qxgeditDial *MultipartAC2LFOAmodDial;
    QGroupBox *MultipartReceiveBox;
    QGridLayout *gridLayout27;
    qxgeditCheck *MultipartPBCheck;
    qxgeditCheck *MultipartCATCheck;
    qxgeditCheck *MultipartPCCheck;
    qxgeditCheck *MultipartCCCheck;
    qxgeditCheck *MultipartPATCheck;
    qxgeditCheck *MultipartNoteCheck;
    qxgeditCheck *MultipartRPNCheck;
    qxgeditCheck *MultipartNRPNCheck;
    qxgeditCheck *MultipartModCheck;
    qxgeditCheck *MultipartVolCheck;
    qxgeditCheck *MultipartPanCheck;
    qxgeditCheck *MultipartExprCheck;
    qxgeditCheck *MultipartHold1Check;
    qxgeditCheck *MultipartPortaCheck;
    qxgeditCheck *MultipartSostCheck;
    qxgeditCheck *MultipartPedalCheck;
    qxgeditCheck *MultipartBankCheck;
    QSpacerItem *spacerItem19;
    QWidget *DrumsetupTab;
    QVBoxLayout *vboxLayout3;
    QHBoxLayout *hboxLayout1;
    QPushButton *DrumsetupResetButton;
    QComboBox *DrumsetupCombo;
    QComboBox *DrumsetupVoiceCombo;
    QComboBox *DrumsetupNoteCombo;
    QSpacerItem *spacerItem20;
    QGridLayout *gridLayout28;
    QGroupBox *DrumsetupPitchBox;
    QGridLayout *gridLayout29;
    qxgeditDial *DrumsetupCoarseDial;
    qxgeditDial *DrumsetupFineDial;
    QGroupBox *DrumsetupControlBox;
    QGridLayout *gridLayout30;
    qxgeditDial *DrumsetupLevelDial;
    qxgeditDial *DrumsetupPanDial;
    QGroupBox *DrumsetupModeBox;
    QGridLayout *gridLayout31;
    qxgeditDial *DrumsetupGroupDial;
    qxgeditDial *DrumsetupKeyAssignDial;
    QGroupBox *DrumsetupEffectBox;
    QGridLayout *gridLayout32;
    qxgeditDial *DrumsetupReverbDial;
    qxgeditDial *DrumsetupChorusDial;
    qxgeditDial *DrumsetupVariationDial;
    QGroupBox *DrumsetupFilterBox;
    QGridLayout *gridLayout33;
    qxgeditFilter *DrumsetupFilter;
    qxgeditDial *DrumsetupCutoffDial;
    qxgeditDial *DrumsetupResonanceDial;
    QGroupBox *DrumsetupAmpEgBox;
    QGridLayout *gridLayout34;
    qxgeditDrumEg *DrumsetupAmpEg;
    qxgeditDial *DrumsetupAttackDial;
    qxgeditDial *DrumsetupDecay1Dial;
    qxgeditDial *DrumsetupDecay2Dial;
    QGroupBox *DrumsetupNoteBox;
    QGridLayout *gridLayout35;
    qxgeditCheck *DrumsetupNoteOnCheck;
    qxgeditCheck *DrumsetupNoteOffCheck;
    QSpacerItem *spacerItem21;
    QSpacerItem *spacerItem22;
    QWidget *UservoiceTab;
    QVBoxLayout *vboxLayout4;
    QHBoxLayout *hboxLayout2;
    QPushButton *UservoiceResetButton;
    QComboBox *UservoiceCombo;
    qxgeditEdit *UservoiceNameEdit;
    QComboBox *UservoiceElementCombo;
    QSpacerItem *spacerItem23;
    QCheckBox *UservoiceAutoSendCheck;
    QPushButton *UservoiceSendButton;
    QTabWidget *UservoiceToolBox;
    QWidget *UservoiceMainPage;
    QGridLayout *gridLayout36;
    QGroupBox *UservoiceCommonBox;
    QGridLayout *gridLayout37;
    qxgeditDial *UservoiceLevelDial;
    qxgeditDial *UservoiceElementDial;
    QGroupBox *UservoiceElementBox;
    QGridLayout *gridLayout38;
    qxgeditDial *UservoiceWaveDial;
    qxgeditDial *UservoiceNoteLowDial;
    qxgeditDial *UservoiceNoteHighDial;
    qxgeditDial *UservoiceVelLowDial;
    qxgeditDial *UservoiceVelHighDial;
    qxgeditDial *UservoiceFEGVelCurveDial;
    QGroupBox *UservoiceLFOBox;
    QGridLayout *gridLayout39;
    qxgeditDial *UservoiceLFOWaveDial;
    qxgeditDial *UservoiceLFOPhaseDial;
    qxgeditDial *UservoiceLFOSpeedDial;
    qxgeditDial *UservoiceLFODelayDial;
    qxgeditDial *UservoiceLFOFadeDial;
    qxgeditDial *UservoiceLFOPitchDial;
    qxgeditDial *UservoiceLFOCutoffDial;
    qxgeditDial *UservoiceLFOAmplDial;
    QSpacerItem *spacerItem24;
    QWidget *UservoiceLevelPage;
    QGridLayout *gridLayout40;
    QGroupBox *UservoiceLevelScaleBox;
    QGridLayout *gridLayout41;
    qxgeditScale *UservoiceLevelScale;
    qxgeditDial *UservoiceLevelBreak1Dial;
    qxgeditDial *UservoiceLevelBreak2Dial;
    qxgeditDial *UservoiceLevelBreak3Dial;
    qxgeditDial *UservoiceLevelBreak4Dial;
    qxgeditDial *UservoiceLevelOffset1Dial;
    qxgeditDial *UservoiceLevelOffset2Dial;
    qxgeditDial *UservoiceLevelOffset3Dial;
    qxgeditDial *UservoiceLevelOffset4Dial;
    QGroupBox *UservoiceLevelParamBox;
    QGridLayout *gridLayout42;
    qxgeditDial *UservoiceElementLevelDial;
    qxgeditDial *UservoiceVelCurveDial;
    qxgeditDial *UservoicePanDial;
    QSpacerItem *spacerItem25;
    QSpacerItem *spacerItem26;
    QWidget *UservoiceCutoffPage;
    QGridLayout *gridLayout43;
    QGroupBox *UservoiceCutoffScaleBox;
    QGridLayout *gridLayout44;
    qxgeditScale *UservoiceCutoffScale;
    qxgeditDial *UservoiceCutoffBreak1Dial;
    qxgeditDial *UservoiceCutoffBreak2Dial;
    qxgeditDial *UservoiceCutoffBreak3Dial;
    qxgeditDial *UservoiceCutoffBreak4Dial;
    qxgeditDial *UservoiceCutoffOffset1Dial;
    qxgeditDial *UservoiceCutoffOffset2Dial;
    qxgeditDial *UservoiceCutoffOffset3Dial;
    qxgeditDial *UservoiceCutoffOffset4Dial;
    QGroupBox *UservoiceFilterFreqBox;
    QGridLayout *gridLayout45;
    qxgeditFilter *UservoiceFilter;
    qxgeditDial *UservoiceCutoffDial;
    qxgeditDial *UservoiceResonanceDial;
    QSpacerItem *spacerItem27;
    QSpacerItem *spacerItem28;
    QSpacerItem *spacerItem29;
    QWidget *UservoiceFilterEgPage;
    QGridLayout *gridLayout46;
    QGroupBox *UservoiceFilterEgBox;
    QGridLayout *gridLayout47;
    qxgeditUserEg *UservoiceFilterEg;
    qxgeditDial *UservoiceFEGLevel0Dial;
    qxgeditDial *UservoiceFEGLevel1Dial;
    qxgeditDial *UservoiceFEGLevel2Dial;
    qxgeditDial *UservoiceFEGLevel3Dial;
    qxgeditDial *UservoiceFEGLevel4Dial;
    qxgeditDial *UservoiceFEGCenterDial;
    qxgeditDial *UservoiceFEGRate1Dial;
    qxgeditDial *UservoiceFEGRate2Dial;
    qxgeditDial *UservoiceFEGRate3Dial;
    qxgeditDial *UservoiceFEGRate4Dial;
    QGroupBox *UservoiceFilterEgParamBox;
    QGridLayout *gridLayout48;
    qxgeditDial *UservoiceVelocityDial;
    qxgeditDial *UservoiceFEGVelLevelDial;
    qxgeditDial *UservoiceFEGVelRateDial;
    qxgeditDial *UservoiceFEGScalingDial;
    QSpacerItem *spacerItem30;
    QSpacerItem *spacerItem31;
    QWidget *UservoicePitchEgPage;
    QGridLayout *gridLayout49;
    QGroupBox *UservoicePitchEgBox;
    QGridLayout *gridLayout50;
    qxgeditUserEg *UservoicePitchEg;
    qxgeditDial *UservoicePEGLevel0Dial;
    qxgeditDial *UservoicePEGLevel1Dial;
    qxgeditDial *UservoicePEGLevel2Dial;
    qxgeditDial *UservoicePEGLevel3Dial;
    qxgeditDial *UservoicePEGLevel4Dial;
    qxgeditDial *UservoicePEGCenterDial;
    qxgeditDial *UservoicePEGRate1Dial;
    qxgeditDial *UservoicePEGRate2Dial;
    qxgeditDial *UservoicePEGRate3Dial;
    qxgeditDial *UservoicePEGRate4Dial;
    QGroupBox *UservoicePitchParamBox;
    QGridLayout *gridLayout51;
    qxgeditDial *UservoiceNoteShiftDial;
    qxgeditDial *UservoiceDetuneDial;
    qxgeditDial *UservoicePitchScalingDial;
    qxgeditDial *UservoicePitchCenterDial;
    qxgeditDial *UservoicePEGDepthDial;
    qxgeditDial *UservoicePEGVelLevelDial;
    qxgeditDial *UservoicePEGVelRateDial;
    qxgeditDial *UservoicePEGScalingDial;
    QSpacerItem *spacerItem32;
    QSpacerItem *spacerItem33;
    QWidget *UservoiceAmpEgPage;
    QGridLayout *gridLayout52;
    QGroupBox *UservoiceAmpEgBox;
    QGridLayout *gridLayout53;
    qxgeditAmpEg *UservoiceAmpEg;
    qxgeditDial *UservoiceAEGAttackDial;
    qxgeditDial *UservoiceAEGDecay1Dial;
    qxgeditDial *UservoiceAEGDecay2Dial;
    qxgeditDial *UservoiceAEGReleaseDial;
    qxgeditDial *UservoiceAEGCenterDial;
    qxgeditDial *UservoiceAEGLevel1Dial;
    qxgeditDial *UservoiceAEGLevel2Dial;
    QGroupBox *UservoiceAmpEgParamBox;
    QGridLayout *gridLayout54;
    qxgeditDial *UservoiceAEGDelayDial;
    qxgeditDial *UservoiceAEGRateDial;
    qxgeditDial *UservoiceAEGOffsetDial;
    qxgeditDial *UservoiceAEGResonanceDial;
    QSpacerItem *spacerItem34;
    QSpacerItem *spacerItem35;
    QToolBar *ToolBar;
    QMenuBar *MenuBar;
    QMenu *fileMenu;
    QMenu *fileOpenRecentMenu;
    QMenu *viewMenu;
    QMenu *helpMenu;

    void setupUi(QMainWindow *qxgeditMainForm)
    {
        if (qxgeditMainForm->objectName().isEmpty())
            qxgeditMainForm->setObjectName("qxgeditMainForm");
        qxgeditMainForm->resize(640, 520);
        qxgeditMainForm->setMinimumSize(QSize(640, 480));
        qxgeditMainForm->setAcceptDrops(true);
        const QIcon icon = QIcon(QString::fromUtf8(":/images/qxgedit.svg"));
        qxgeditMainForm->setWindowIcon(icon);
        fileNewAction = new QAction(qxgeditMainForm);
        fileNewAction->setObjectName("fileNewAction");
        const QIcon icon1 = QIcon(QString::fromUtf8(":/images/fileNew.png"));
        fileNewAction->setIcon(icon1);
        fileOpenAction = new QAction(qxgeditMainForm);
        fileOpenAction->setObjectName("fileOpenAction");
        const QIcon icon2 = QIcon(QString::fromUtf8(":/images/fileOpen.png"));
        fileOpenAction->setIcon(icon2);
        fileSaveAction = new QAction(qxgeditMainForm);
        fileSaveAction->setObjectName("fileSaveAction");
        const QIcon icon3 = QIcon(QString::fromUtf8(":/images/fileSave.png"));
        fileSaveAction->setIcon(icon3);
        fileSaveAsAction = new QAction(qxgeditMainForm);
        fileSaveAsAction->setObjectName("fileSaveAsAction");
        fileExitAction = new QAction(qxgeditMainForm);
        fileExitAction->setObjectName("fileExitAction");
        viewMenubarAction = new QAction(qxgeditMainForm);
        viewMenubarAction->setObjectName("viewMenubarAction");
        viewMenubarAction->setCheckable(true);
        viewStatusbarAction = new QAction(qxgeditMainForm);
        viewStatusbarAction->setObjectName("viewStatusbarAction");
        viewStatusbarAction->setCheckable(true);
        viewToolbarAction = new QAction(qxgeditMainForm);
        viewToolbarAction->setObjectName("viewToolbarAction");
        viewToolbarAction->setCheckable(true);
        viewRandomizeAction = new QAction(qxgeditMainForm);
        viewRandomizeAction->setObjectName("viewRandomizeAction");
        const QIcon icon4 = QIcon(QString::fromUtf8(":/images/formCreate.png"));
        viewRandomizeAction->setIcon(icon4);
        viewOptionsAction = new QAction(qxgeditMainForm);
        viewOptionsAction->setObjectName("viewOptionsAction");
        helpAboutAction = new QAction(qxgeditMainForm);
        helpAboutAction->setObjectName("helpAboutAction");
        helpAboutQtAction = new QAction(qxgeditMainForm);
        helpAboutQtAction->setObjectName("helpAboutQtAction");
        MainCentralWidget = new QWidget(qxgeditMainForm);
        MainCentralWidget->setObjectName("MainCentralWidget");
        vboxLayout = new QVBoxLayout(MainCentralWidget);
        vboxLayout->setSpacing(4);
        vboxLayout->setContentsMargins(4, 4, 4, 4);
        vboxLayout->setObjectName("vboxLayout");
        MainTabWidget = new QTabWidget(MainCentralWidget);
        MainTabWidget->setObjectName("MainTabWidget");
        SystemEffectTab = new QWidget();
        SystemEffectTab->setObjectName("SystemEffectTab");
        vboxLayout1 = new QVBoxLayout(SystemEffectTab);
        vboxLayout1->setSpacing(4);
        vboxLayout1->setContentsMargins(4, 4, 4, 4);
        vboxLayout1->setObjectName("vboxLayout1");
        SystemEffectToolBox = new QTabWidget(SystemEffectTab);
        SystemEffectToolBox->setObjectName("SystemEffectToolBox");
        SYSTEMPage = new QWidget();
        SYSTEMPage->setObjectName("SYSTEMPage");
        gridLayout = new QGridLayout(SYSTEMPage);
        gridLayout->setSpacing(4);
        gridLayout->setContentsMargins(4, 4, 4, 4);
        gridLayout->setObjectName("gridLayout");
        MasterResetButton = new QPushButton(SYSTEMPage);
        MasterResetButton->setObjectName("MasterResetButton");
        MasterResetButton->setIcon(icon);

        gridLayout->addWidget(MasterResetButton, 0, 0, 1, 1);

        MasterTuneDial = new qxgeditDial(SYSTEMPage);
        MasterTuneDial->setObjectName("MasterTuneDial");

        gridLayout->addWidget(MasterTuneDial, 0, 1, 1, 1);

        MasterVolumeDial = new qxgeditDial(SYSTEMPage);
        MasterVolumeDial->setObjectName("MasterVolumeDial");

        gridLayout->addWidget(MasterVolumeDial, 0, 2, 1, 1);

        MasterTransposeDial = new qxgeditDial(SYSTEMPage);
        MasterTransposeDial->setObjectName("MasterTransposeDial");

        gridLayout->addWidget(MasterTransposeDial, 0, 3, 1, 1);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 0, 4, 1, 1);

        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem1, 1, 0, 1, 5);

        SystemEffectToolBox->addTab(SYSTEMPage, QString());
        ReverbPage = new QWidget();
        ReverbPage->setObjectName("ReverbPage");
        gridLayout1 = new QGridLayout(ReverbPage);
        gridLayout1->setSpacing(4);
        gridLayout1->setContentsMargins(4, 4, 4, 4);
        gridLayout1->setObjectName("gridLayout1");
        ReverbResetButton = new QPushButton(ReverbPage);
        ReverbResetButton->setObjectName("ReverbResetButton");

        gridLayout1->addWidget(ReverbResetButton, 0, 0, 1, 1);

        ReverbTypeCombo = new qxgeditCombo(ReverbPage);
        ReverbTypeCombo->setObjectName("ReverbTypeCombo");

        gridLayout1->addWidget(ReverbTypeCombo, 0, 1, 1, 3);

        spacerItem2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem2, 0, 4, 1, 6);

        spacerItem3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem3, 0, 10, 3, 1);

        ReverbParam1Dial = new qxgeditDial(ReverbPage);
        ReverbParam1Dial->setObjectName("ReverbParam1Dial");

        gridLayout1->addWidget(ReverbParam1Dial, 1, 0, 1, 1);

        ReverbParam2Dial = new qxgeditDial(ReverbPage);
        ReverbParam2Dial->setObjectName("ReverbParam2Dial");

        gridLayout1->addWidget(ReverbParam2Dial, 1, 1, 1, 1);

        ReverbParam3Dial = new qxgeditDial(ReverbPage);
        ReverbParam3Dial->setObjectName("ReverbParam3Dial");

        gridLayout1->addWidget(ReverbParam3Dial, 1, 2, 1, 1);

        ReverbParam4Dial = new qxgeditDial(ReverbPage);
        ReverbParam4Dial->setObjectName("ReverbParam4Dial");

        gridLayout1->addWidget(ReverbParam4Dial, 1, 3, 1, 1);

        ReverbParam5Dial = new qxgeditDial(ReverbPage);
        ReverbParam5Dial->setObjectName("ReverbParam5Dial");

        gridLayout1->addWidget(ReverbParam5Dial, 1, 4, 1, 1);

        ReverbParam6Dial = new qxgeditDial(ReverbPage);
        ReverbParam6Dial->setObjectName("ReverbParam6Dial");

        gridLayout1->addWidget(ReverbParam6Dial, 1, 5, 1, 1);

        ReverbParam7Dial = new qxgeditDial(ReverbPage);
        ReverbParam7Dial->setObjectName("ReverbParam7Dial");

        gridLayout1->addWidget(ReverbParam7Dial, 1, 6, 1, 1);

        ReverbParam8Dial = new qxgeditDial(ReverbPage);
        ReverbParam8Dial->setObjectName("ReverbParam8Dial");

        gridLayout1->addWidget(ReverbParam8Dial, 1, 7, 1, 1);

        ReverbParam9Dial = new qxgeditDial(ReverbPage);
        ReverbParam9Dial->setObjectName("ReverbParam9Dial");

        gridLayout1->addWidget(ReverbParam9Dial, 1, 8, 1, 1);

        ReverbParam10Dial = new qxgeditDial(ReverbPage);
        ReverbParam10Dial->setObjectName("ReverbParam10Dial");

        gridLayout1->addWidget(ReverbParam10Dial, 1, 9, 1, 1);

        ReverbReturnDial = new qxgeditDial(ReverbPage);
        ReverbReturnDial->setObjectName("ReverbReturnDial");

        gridLayout1->addWidget(ReverbReturnDial, 2, 0, 1, 1);

        ReverbPanDial = new qxgeditDial(ReverbPage);
        ReverbPanDial->setObjectName("ReverbPanDial");

        gridLayout1->addWidget(ReverbPanDial, 2, 1, 1, 1);

        ReverbParam11Dial = new qxgeditDial(ReverbPage);
        ReverbParam11Dial->setObjectName("ReverbParam11Dial");

        gridLayout1->addWidget(ReverbParam11Dial, 2, 2, 1, 1);

        ReverbParam12Dial = new qxgeditDial(ReverbPage);
        ReverbParam12Dial->setObjectName("ReverbParam12Dial");

        gridLayout1->addWidget(ReverbParam12Dial, 2, 3, 1, 1);

        ReverbParam13Dial = new qxgeditDial(ReverbPage);
        ReverbParam13Dial->setObjectName("ReverbParam13Dial");

        gridLayout1->addWidget(ReverbParam13Dial, 2, 4, 1, 1);

        ReverbParam14Dial = new qxgeditDial(ReverbPage);
        ReverbParam14Dial->setObjectName("ReverbParam14Dial");

        gridLayout1->addWidget(ReverbParam14Dial, 2, 5, 1, 1);

        ReverbParam15Dial = new qxgeditDial(ReverbPage);
        ReverbParam15Dial->setObjectName("ReverbParam15Dial");

        gridLayout1->addWidget(ReverbParam15Dial, 2, 6, 1, 1);

        ReverbParam16Dial = new qxgeditDial(ReverbPage);
        ReverbParam16Dial->setObjectName("ReverbParam16Dial");

        gridLayout1->addWidget(ReverbParam16Dial, 2, 7, 1, 1);

        spacerItem4 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout1->addItem(spacerItem4, 3, 0, 1, 11);

        SystemEffectToolBox->addTab(ReverbPage, QString());
        ChorusPage = new QWidget();
        ChorusPage->setObjectName("ChorusPage");
        gridLayout2 = new QGridLayout(ChorusPage);
        gridLayout2->setSpacing(4);
        gridLayout2->setContentsMargins(4, 4, 4, 4);
        gridLayout2->setObjectName("gridLayout2");
        ChorusResetButton = new QPushButton(ChorusPage);
        ChorusResetButton->setObjectName("ChorusResetButton");

        gridLayout2->addWidget(ChorusResetButton, 0, 0, 1, 1);

        ChorusTypeCombo = new qxgeditCombo(ChorusPage);
        ChorusTypeCombo->setObjectName("ChorusTypeCombo");

        gridLayout2->addWidget(ChorusTypeCombo, 0, 1, 1, 3);

        spacerItem5 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(spacerItem5, 0, 4, 1, 6);

        spacerItem6 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(spacerItem6, 0, 10, 3, 1);

        ChorusParam1Dial = new qxgeditDial(ChorusPage);
        ChorusParam1Dial->setObjectName("ChorusParam1Dial");

        gridLayout2->addWidget(ChorusParam1Dial, 1, 0, 1, 1);

        ChorusParam2Dial = new qxgeditDial(ChorusPage);
        ChorusParam2Dial->setObjectName("ChorusParam2Dial");

        gridLayout2->addWidget(ChorusParam2Dial, 1, 1, 1, 1);

        ChorusParam3Dial = new qxgeditDial(ChorusPage);
        ChorusParam3Dial->setObjectName("ChorusParam3Dial");

        gridLayout2->addWidget(ChorusParam3Dial, 1, 2, 1, 1);

        ChorusParam4Dial = new qxgeditDial(ChorusPage);
        ChorusParam4Dial->setObjectName("ChorusParam4Dial");

        gridLayout2->addWidget(ChorusParam4Dial, 1, 3, 1, 1);

        ChorusParam5Dial = new qxgeditDial(ChorusPage);
        ChorusParam5Dial->setObjectName("ChorusParam5Dial");

        gridLayout2->addWidget(ChorusParam5Dial, 1, 4, 1, 1);

        ChorusParam6Dial = new qxgeditDial(ChorusPage);
        ChorusParam6Dial->setObjectName("ChorusParam6Dial");

        gridLayout2->addWidget(ChorusParam6Dial, 1, 5, 1, 1);

        ChorusParam7Dial = new qxgeditDial(ChorusPage);
        ChorusParam7Dial->setObjectName("ChorusParam7Dial");

        gridLayout2->addWidget(ChorusParam7Dial, 1, 6, 1, 1);

        ChorusParam8Dial = new qxgeditDial(ChorusPage);
        ChorusParam8Dial->setObjectName("ChorusParam8Dial");

        gridLayout2->addWidget(ChorusParam8Dial, 1, 7, 1, 1);

        ChorusParam9Dial = new qxgeditDial(ChorusPage);
        ChorusParam9Dial->setObjectName("ChorusParam9Dial");

        gridLayout2->addWidget(ChorusParam9Dial, 1, 8, 1, 1);

        ChorusParam10Dial = new qxgeditDial(ChorusPage);
        ChorusParam10Dial->setObjectName("ChorusParam10Dial");

        gridLayout2->addWidget(ChorusParam10Dial, 1, 9, 1, 1);

        ChorusReturnDial = new qxgeditDial(ChorusPage);
        ChorusReturnDial->setObjectName("ChorusReturnDial");

        gridLayout2->addWidget(ChorusReturnDial, 2, 0, 1, 1);

        ChorusPanDial = new qxgeditDial(ChorusPage);
        ChorusPanDial->setObjectName("ChorusPanDial");

        gridLayout2->addWidget(ChorusPanDial, 2, 1, 1, 1);

        ChorusReverbDial = new qxgeditDial(ChorusPage);
        ChorusReverbDial->setObjectName("ChorusReverbDial");

        gridLayout2->addWidget(ChorusReverbDial, 2, 2, 1, 1);

        ChorusParam11Dial = new qxgeditDial(ChorusPage);
        ChorusParam11Dial->setObjectName("ChorusParam11Dial");

        gridLayout2->addWidget(ChorusParam11Dial, 2, 3, 1, 1);

        ChorusParam12Dial = new qxgeditDial(ChorusPage);
        ChorusParam12Dial->setObjectName("ChorusParam12Dial");

        gridLayout2->addWidget(ChorusParam12Dial, 2, 4, 1, 1);

        ChorusParam13Dial = new qxgeditDial(ChorusPage);
        ChorusParam13Dial->setObjectName("ChorusParam13Dial");

        gridLayout2->addWidget(ChorusParam13Dial, 2, 5, 1, 1);

        ChorusParam14Dial = new qxgeditDial(ChorusPage);
        ChorusParam14Dial->setObjectName("ChorusParam14Dial");

        gridLayout2->addWidget(ChorusParam14Dial, 2, 6, 1, 1);

        ChorusParam15Dial = new qxgeditDial(ChorusPage);
        ChorusParam15Dial->setObjectName("ChorusParam15Dial");

        gridLayout2->addWidget(ChorusParam15Dial, 2, 7, 1, 1);

        ChorusParam16Dial = new qxgeditDial(ChorusPage);
        ChorusParam16Dial->setObjectName("ChorusParam16Dial");

        gridLayout2->addWidget(ChorusParam16Dial, 2, 8, 1, 1);

        spacerItem7 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout2->addItem(spacerItem7, 3, 0, 1, 11);

        SystemEffectToolBox->addTab(ChorusPage, QString());
        VariationPage = new QWidget();
        VariationPage->setObjectName("VariationPage");
        gridLayout3 = new QGridLayout(VariationPage);
        gridLayout3->setSpacing(4);
        gridLayout3->setContentsMargins(4, 4, 4, 4);
        gridLayout3->setObjectName("gridLayout3");
        VariationResetButton = new QPushButton(VariationPage);
        VariationResetButton->setObjectName("VariationResetButton");

        gridLayout3->addWidget(VariationResetButton, 0, 0, 1, 1);

        VariationTypeCombo = new qxgeditCombo(VariationPage);
        VariationTypeCombo->setObjectName("VariationTypeCombo");

        gridLayout3->addWidget(VariationTypeCombo, 0, 1, 1, 3);

        spacerItem8 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacerItem8, 0, 4, 1, 6);

        spacerItem9 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacerItem9, 0, 10, 4, 1);

        VariationParam1Dial = new qxgeditDial(VariationPage);
        VariationParam1Dial->setObjectName("VariationParam1Dial");

        gridLayout3->addWidget(VariationParam1Dial, 1, 0, 1, 1);

        VariationParam2Dial = new qxgeditDial(VariationPage);
        VariationParam2Dial->setObjectName("VariationParam2Dial");

        gridLayout3->addWidget(VariationParam2Dial, 1, 1, 1, 1);

        VariationParam3Dial = new qxgeditDial(VariationPage);
        VariationParam3Dial->setObjectName("VariationParam3Dial");

        gridLayout3->addWidget(VariationParam3Dial, 1, 2, 1, 1);

        VariationParam4Dial = new qxgeditDial(VariationPage);
        VariationParam4Dial->setObjectName("VariationParam4Dial");

        gridLayout3->addWidget(VariationParam4Dial, 1, 3, 1, 1);

        VariationParam5Dial = new qxgeditDial(VariationPage);
        VariationParam5Dial->setObjectName("VariationParam5Dial");

        gridLayout3->addWidget(VariationParam5Dial, 1, 4, 1, 1);

        VariationParam6Dial = new qxgeditDial(VariationPage);
        VariationParam6Dial->setObjectName("VariationParam6Dial");

        gridLayout3->addWidget(VariationParam6Dial, 1, 5, 1, 1);

        VariationParam7Dial = new qxgeditDial(VariationPage);
        VariationParam7Dial->setObjectName("VariationParam7Dial");

        gridLayout3->addWidget(VariationParam7Dial, 1, 6, 1, 1);

        VariationParam8Dial = new qxgeditDial(VariationPage);
        VariationParam8Dial->setObjectName("VariationParam8Dial");

        gridLayout3->addWidget(VariationParam8Dial, 1, 7, 1, 1);

        VariationParam9Dial = new qxgeditDial(VariationPage);
        VariationParam9Dial->setObjectName("VariationParam9Dial");

        gridLayout3->addWidget(VariationParam9Dial, 1, 8, 1, 1);

        VariationParam10Dial = new qxgeditDial(VariationPage);
        VariationParam10Dial->setObjectName("VariationParam10Dial");

        gridLayout3->addWidget(VariationParam10Dial, 1, 9, 1, 1);

        VariationReturnDial = new qxgeditDial(VariationPage);
        VariationReturnDial->setObjectName("VariationReturnDial");

        gridLayout3->addWidget(VariationReturnDial, 2, 0, 1, 1);

        VariationPanDial = new qxgeditDial(VariationPage);
        VariationPanDial->setObjectName("VariationPanDial");

        gridLayout3->addWidget(VariationPanDial, 2, 1, 1, 1);

        VariationReverbDial = new qxgeditDial(VariationPage);
        VariationReverbDial->setObjectName("VariationReverbDial");

        gridLayout3->addWidget(VariationReverbDial, 2, 2, 1, 1);

        VariationChorusDial = new qxgeditDial(VariationPage);
        VariationChorusDial->setObjectName("VariationChorusDial");

        gridLayout3->addWidget(VariationChorusDial, 2, 3, 1, 1);

        VariationConnectDial = new qxgeditDial(VariationPage);
        VariationConnectDial->setObjectName("VariationConnectDial");

        gridLayout3->addWidget(VariationConnectDial, 2, 4, 1, 1);

        VariationPartDial = new qxgeditDial(VariationPage);
        VariationPartDial->setObjectName("VariationPartDial");

        gridLayout3->addWidget(VariationPartDial, 2, 5, 1, 1);

        VariationWheelDial = new qxgeditDial(VariationPage);
        VariationWheelDial->setObjectName("VariationWheelDial");

        gridLayout3->addWidget(VariationWheelDial, 2, 6, 1, 1);

        VariationBendDial = new qxgeditDial(VariationPage);
        VariationBendDial->setObjectName("VariationBendDial");

        gridLayout3->addWidget(VariationBendDial, 2, 7, 1, 1);

        VariationCATDial = new qxgeditDial(VariationPage);
        VariationCATDial->setObjectName("VariationCATDial");

        gridLayout3->addWidget(VariationCATDial, 2, 8, 1, 1);

        VariationAC1Dial = new qxgeditDial(VariationPage);
        VariationAC1Dial->setObjectName("VariationAC1Dial");

        gridLayout3->addWidget(VariationAC1Dial, 2, 9, 1, 1);

        VariationAC2Dial = new qxgeditDial(VariationPage);
        VariationAC2Dial->setObjectName("VariationAC2Dial");

        gridLayout3->addWidget(VariationAC2Dial, 3, 0, 1, 1);

        VariationParam11Dial = new qxgeditDial(VariationPage);
        VariationParam11Dial->setObjectName("VariationParam11Dial");

        gridLayout3->addWidget(VariationParam11Dial, 3, 1, 1, 1);

        VariationParam12Dial = new qxgeditDial(VariationPage);
        VariationParam12Dial->setObjectName("VariationParam12Dial");

        gridLayout3->addWidget(VariationParam12Dial, 3, 2, 1, 1);

        VariationParam13Dial = new qxgeditDial(VariationPage);
        VariationParam13Dial->setObjectName("VariationParam13Dial");

        gridLayout3->addWidget(VariationParam13Dial, 3, 3, 1, 1);

        VariationParam14Dial = new qxgeditDial(VariationPage);
        VariationParam14Dial->setObjectName("VariationParam14Dial");

        gridLayout3->addWidget(VariationParam14Dial, 3, 4, 1, 1);

        VariationParam15Dial = new qxgeditDial(VariationPage);
        VariationParam15Dial->setObjectName("VariationParam15Dial");

        gridLayout3->addWidget(VariationParam15Dial, 3, 5, 1, 1);

        VariationParam16Dial = new qxgeditDial(VariationPage);
        VariationParam16Dial->setObjectName("VariationParam16Dial");

        gridLayout3->addWidget(VariationParam16Dial, 3, 6, 1, 1);

        spacerItem10 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout3->addItem(spacerItem10, 4, 0, 1, 11);

        SystemEffectToolBox->addTab(VariationPage, QString());

        vboxLayout1->addWidget(SystemEffectToolBox);

        MainTabWidget->addTab(SystemEffectTab, QString());
        MultipartTab = new QWidget();
        MultipartTab->setObjectName("MultipartTab");
        vboxLayout2 = new QVBoxLayout(MultipartTab);
        vboxLayout2->setSpacing(4);
        vboxLayout2->setContentsMargins(4, 4, 4, 4);
        vboxLayout2->setObjectName("vboxLayout2");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(4);
        hboxLayout->setObjectName("hboxLayout");
        MultipartResetButton = new QPushButton(MultipartTab);
        MultipartResetButton->setObjectName("MultipartResetButton");

        hboxLayout->addWidget(MultipartResetButton);

        MultipartCombo = new QComboBox(MultipartTab);
        MultipartCombo->setObjectName("MultipartCombo");

        hboxLayout->addWidget(MultipartCombo);

        MultipartVoiceCombo = new QComboBox(MultipartTab);
        MultipartVoiceCombo->setObjectName("MultipartVoiceCombo");

        hboxLayout->addWidget(MultipartVoiceCombo);

        spacerItem11 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem11);


        vboxLayout2->addLayout(hboxLayout);

        MultipartToolBox = new QTabWidget(MultipartTab);
        MultipartToolBox->setObjectName("MultipartToolBox");
        MultipartMainPage = new QWidget();
        MultipartMainPage->setObjectName("MultipartMainPage");
        gridLayout4 = new QGridLayout(MultipartMainPage);
        gridLayout4->setSpacing(4);
        gridLayout4->setContentsMargins(4, 4, 4, 4);
        gridLayout4->setObjectName("gridLayout4");
        MultipartPartBox = new QGroupBox(MultipartMainPage);
        MultipartPartBox->setObjectName("MultipartPartBox");
        gridLayout5 = new QGridLayout(MultipartPartBox);
        gridLayout5->setSpacing(4);
        gridLayout5->setContentsMargins(4, 4, 4, 4);
        gridLayout5->setObjectName("gridLayout5");
        MultipartChannelDial = new qxgeditDial(MultipartPartBox);
        MultipartChannelDial->setObjectName("MultipartChannelDial");

        gridLayout5->addWidget(MultipartChannelDial, 0, 0, 1, 1);

        MultipartElementDial = new qxgeditDial(MultipartPartBox);
        MultipartElementDial->setObjectName("MultipartElementDial");

        gridLayout5->addWidget(MultipartElementDial, 0, 1, 1, 1);


        gridLayout4->addWidget(MultipartPartBox, 0, 0, 1, 2);

        MultipartVoiceBox = new QGroupBox(MultipartMainPage);
        MultipartVoiceBox->setObjectName("MultipartVoiceBox");
        gridLayout6 = new QGridLayout(MultipartVoiceBox);
        gridLayout6->setSpacing(4);
        gridLayout6->setContentsMargins(4, 4, 4, 4);
        gridLayout6->setObjectName("gridLayout6");
        MultipartBankMSBDial = new qxgeditDial(MultipartVoiceBox);
        MultipartBankMSBDial->setObjectName("MultipartBankMSBDial");

        gridLayout6->addWidget(MultipartBankMSBDial, 0, 0, 1, 1);

        MultipartBankLSBDial = new qxgeditDial(MultipartVoiceBox);
        MultipartBankLSBDial->setObjectName("MultipartBankLSBDial");

        gridLayout6->addWidget(MultipartBankLSBDial, 0, 1, 1, 1);

        MultipartProgramDial = new qxgeditDial(MultipartVoiceBox);
        MultipartProgramDial->setObjectName("MultipartProgramDial");

        gridLayout6->addWidget(MultipartProgramDial, 0, 2, 1, 1);


        gridLayout4->addWidget(MultipartVoiceBox, 0, 2, 1, 3);

        MultipartModeBox = new QGroupBox(MultipartMainPage);
        MultipartModeBox->setObjectName("MultipartModeBox");
        gridLayout7 = new QGridLayout(MultipartModeBox);
        gridLayout7->setSpacing(4);
        gridLayout7->setContentsMargins(4, 4, 4, 4);
        gridLayout7->setObjectName("gridLayout7");
        MultipartPolyModeDial = new qxgeditDial(MultipartModeBox);
        MultipartPolyModeDial->setObjectName("MultipartPolyModeDial");

        gridLayout7->addWidget(MultipartPolyModeDial, 0, 0, 1, 1);

        MultipartKeyAssignDial = new qxgeditDial(MultipartModeBox);
        MultipartKeyAssignDial->setObjectName("MultipartKeyAssignDial");

        gridLayout7->addWidget(MultipartKeyAssignDial, 0, 1, 1, 1);

        MultipartPartModeDial = new qxgeditDial(MultipartModeBox);
        MultipartPartModeDial->setObjectName("MultipartPartModeDial");

        gridLayout7->addWidget(MultipartPartModeDial, 0, 2, 1, 1);


        gridLayout4->addWidget(MultipartModeBox, 0, 5, 1, 3);

        MultipartControlBox = new QGroupBox(MultipartMainPage);
        MultipartControlBox->setObjectName("MultipartControlBox");
        gridLayout8 = new QGridLayout(MultipartControlBox);
        gridLayout8->setSpacing(4);
        gridLayout8->setContentsMargins(4, 4, 4, 4);
        gridLayout8->setObjectName("gridLayout8");
        MultipartVolumeDial = new qxgeditDial(MultipartControlBox);
        MultipartVolumeDial->setObjectName("MultipartVolumeDial");

        gridLayout8->addWidget(MultipartVolumeDial, 0, 0, 1, 1);

        MultipartPanDial = new qxgeditDial(MultipartControlBox);
        MultipartPanDial->setObjectName("MultipartPanDial");

        gridLayout8->addWidget(MultipartPanDial, 0, 1, 1, 1);


        gridLayout4->addWidget(MultipartControlBox, 1, 0, 1, 2);

        MultipartPortamentoBox = new QGroupBox(MultipartMainPage);
        MultipartPortamentoBox->setObjectName("MultipartPortamentoBox");
        gridLayout9 = new QGridLayout(MultipartPortamentoBox);
        gridLayout9->setSpacing(4);
        gridLayout9->setContentsMargins(4, 4, 4, 4);
        gridLayout9->setObjectName("gridLayout9");
        MultipartPortamentoDial = new qxgeditDial(MultipartPortamentoBox);
        MultipartPortamentoDial->setObjectName("MultipartPortamentoDial");

        gridLayout9->addWidget(MultipartPortamentoDial, 0, 0, 1, 1);

        MultipartPortaTimeDial = new qxgeditDial(MultipartPortamentoBox);
        MultipartPortaTimeDial->setObjectName("MultipartPortaTimeDial");

        gridLayout9->addWidget(MultipartPortaTimeDial, 0, 1, 1, 1);


        gridLayout4->addWidget(MultipartPortamentoBox, 1, 2, 1, 2);

        MultipartNoteBox = new QGroupBox(MultipartMainPage);
        MultipartNoteBox->setObjectName("MultipartNoteBox");
        gridLayout10 = new QGridLayout(MultipartNoteBox);
        gridLayout10->setSpacing(4);
        gridLayout10->setContentsMargins(4, 4, 4, 4);
        gridLayout10->setObjectName("gridLayout10");
        MultipartNoteLowDial = new qxgeditDial(MultipartNoteBox);
        MultipartNoteLowDial->setObjectName("MultipartNoteLowDial");

        gridLayout10->addWidget(MultipartNoteLowDial, 0, 0, 1, 1);

        MultipartNoteHighDial = new qxgeditDial(MultipartNoteBox);
        MultipartNoteHighDial->setObjectName("MultipartNoteHighDial");

        gridLayout10->addWidget(MultipartNoteHighDial, 0, 1, 1, 1);

        MultipartNoteShiftDial = new qxgeditDial(MultipartNoteBox);
        MultipartNoteShiftDial->setObjectName("MultipartNoteShiftDial");

        gridLayout10->addWidget(MultipartNoteShiftDial, 0, 2, 1, 1);

        MultipartDetuneDial = new qxgeditDial(MultipartNoteBox);
        MultipartDetuneDial->setObjectName("MultipartDetuneDial");

        gridLayout10->addWidget(MultipartDetuneDial, 0, 3, 1, 1);


        gridLayout4->addWidget(MultipartNoteBox, 1, 4, 1, 4);

        MultipartVelocityBox = new QGroupBox(MultipartMainPage);
        MultipartVelocityBox->setObjectName("MultipartVelocityBox");
        gridLayout11 = new QGridLayout(MultipartVelocityBox);
        gridLayout11->setSpacing(4);
        gridLayout11->setContentsMargins(4, 4, 4, 4);
        gridLayout11->setObjectName("gridLayout11");
        MultipartVelDepthDial = new qxgeditDial(MultipartVelocityBox);
        MultipartVelDepthDial->setObjectName("MultipartVelDepthDial");

        gridLayout11->addWidget(MultipartVelDepthDial, 0, 0, 1, 1);

        MultipartVelOffsetDial = new qxgeditDial(MultipartVelocityBox);
        MultipartVelOffsetDial->setObjectName("MultipartVelOffsetDial");

        gridLayout11->addWidget(MultipartVelOffsetDial, 0, 1, 1, 1);

        MultipartVelLowDial = new qxgeditDial(MultipartVelocityBox);
        MultipartVelLowDial->setObjectName("MultipartVelLowDial");

        gridLayout11->addWidget(MultipartVelLowDial, 0, 2, 1, 1);

        MultipartVelHighDial = new qxgeditDial(MultipartVelocityBox);
        MultipartVelHighDial->setObjectName("MultipartVelHighDial");

        gridLayout11->addWidget(MultipartVelHighDial, 0, 3, 1, 1);


        gridLayout4->addWidget(MultipartVelocityBox, 2, 0, 1, 4);

        MultipartEffectBox = new QGroupBox(MultipartMainPage);
        MultipartEffectBox->setObjectName("MultipartEffectBox");
        gridLayout12 = new QGridLayout(MultipartEffectBox);
        gridLayout12->setSpacing(4);
        gridLayout12->setContentsMargins(4, 4, 4, 4);
        gridLayout12->setObjectName("gridLayout12");
        MultipartDryWetDial = new qxgeditDial(MultipartEffectBox);
        MultipartDryWetDial->setObjectName("MultipartDryWetDial");

        gridLayout12->addWidget(MultipartDryWetDial, 0, 0, 1, 1);

        MultipartChorusDial = new qxgeditDial(MultipartEffectBox);
        MultipartChorusDial->setObjectName("MultipartChorusDial");

        gridLayout12->addWidget(MultipartChorusDial, 0, 1, 1, 1);

        MultipartReverbDial = new qxgeditDial(MultipartEffectBox);
        MultipartReverbDial->setObjectName("MultipartReverbDial");

        gridLayout12->addWidget(MultipartReverbDial, 0, 2, 1, 1);

        MultipartVariationDial = new qxgeditDial(MultipartEffectBox);
        MultipartVariationDial->setObjectName("MultipartVariationDial");

        gridLayout12->addWidget(MultipartVariationDial, 0, 3, 1, 1);


        gridLayout4->addWidget(MultipartEffectBox, 2, 4, 1, 4);

        spacerItem12 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout4->addItem(spacerItem12, 4, 0, 1, 8);

        MultipartToolBox->addTab(MultipartMainPage, QString());
        MultipartTonePage = new QWidget();
        MultipartTonePage->setObjectName("MultipartTonePage");
        gridLayout13 = new QGridLayout(MultipartTonePage);
        gridLayout13->setSpacing(4);
        gridLayout13->setContentsMargins(4, 4, 4, 4);
        gridLayout13->setObjectName("gridLayout13");
        MultipartVibratoBox = new QGroupBox(MultipartTonePage);
        MultipartVibratoBox->setObjectName("MultipartVibratoBox");
        gridLayout14 = new QGridLayout(MultipartVibratoBox);
        gridLayout14->setSpacing(4);
        gridLayout14->setContentsMargins(4, 4, 4, 4);
        gridLayout14->setObjectName("gridLayout14");
        MultipartVibra = new qxgeditVibra(MultipartVibratoBox);
        MultipartVibra->setObjectName("MultipartVibra");

        gridLayout14->addWidget(MultipartVibra, 0, 0, 1, 4);

        MultipartRateDial = new qxgeditDial(MultipartVibratoBox);
        MultipartRateDial->setObjectName("MultipartRateDial");

        gridLayout14->addWidget(MultipartRateDial, 1, 0, 1, 1);

        MultipartDepthDial = new qxgeditDial(MultipartVibratoBox);
        MultipartDepthDial->setObjectName("MultipartDepthDial");

        gridLayout14->addWidget(MultipartDepthDial, 1, 1, 1, 1);

        MultipartDelayDial = new qxgeditDial(MultipartVibratoBox);
        MultipartDelayDial->setObjectName("MultipartDelayDial");

        gridLayout14->addWidget(MultipartDelayDial, 1, 2, 1, 1);

        spacerItem13 = new QSpacerItem(60, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout14->addItem(spacerItem13, 1, 3, 1, 1);


        gridLayout13->addWidget(MultipartVibratoBox, 0, 0, 1, 1);

        MultipartFilterBox = new QGroupBox(MultipartTonePage);
        MultipartFilterBox->setObjectName("MultipartFilterBox");
        gridLayout15 = new QGridLayout(MultipartFilterBox);
        gridLayout15->setSpacing(4);
        gridLayout15->setContentsMargins(4, 4, 4, 4);
        gridLayout15->setObjectName("gridLayout15");
        MultipartFilter = new qxgeditFilter(MultipartFilterBox);
        MultipartFilter->setObjectName("MultipartFilter");

        gridLayout15->addWidget(MultipartFilter, 0, 0, 1, 5);

        MultipartCutoffDial = new qxgeditDial(MultipartFilterBox);
        MultipartCutoffDial->setObjectName("MultipartCutoffDial");

        gridLayout15->addWidget(MultipartCutoffDial, 1, 0, 1, 1);

        MultipartResonanceDial = new qxgeditDial(MultipartFilterBox);
        MultipartResonanceDial->setObjectName("MultipartResonanceDial");

        gridLayout15->addWidget(MultipartResonanceDial, 1, 1, 1, 1);

        spacerItem14 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout15->addItem(spacerItem14, 1, 2, 1, 3);


        gridLayout13->addWidget(MultipartFilterBox, 0, 1, 1, 1);

        MultipartAmpEgBox = new QGroupBox(MultipartTonePage);
        MultipartAmpEgBox->setObjectName("MultipartAmpEgBox");
        gridLayout16 = new QGridLayout(MultipartAmpEgBox);
        gridLayout16->setSpacing(4);
        gridLayout16->setContentsMargins(4, 4, 4, 4);
        gridLayout16->setObjectName("gridLayout16");
        MultipartAmpEg = new qxgeditPartEg(MultipartAmpEgBox);
        MultipartAmpEg->setObjectName("MultipartAmpEg");

        gridLayout16->addWidget(MultipartAmpEg, 0, 0, 1, 4);

        MultipartAttackDial = new qxgeditDial(MultipartAmpEgBox);
        MultipartAttackDial->setObjectName("MultipartAttackDial");

        gridLayout16->addWidget(MultipartAttackDial, 1, 0, 1, 1);

        MultipartDecayDial = new qxgeditDial(MultipartAmpEgBox);
        MultipartDecayDial->setObjectName("MultipartDecayDial");

        gridLayout16->addWidget(MultipartDecayDial, 1, 1, 1, 1);

        MultipartReleaseDial = new qxgeditDial(MultipartAmpEgBox);
        MultipartReleaseDial->setObjectName("MultipartReleaseDial");

        gridLayout16->addWidget(MultipartReleaseDial, 1, 2, 1, 1);

        spacerItem15 = new QSpacerItem(60, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout16->addItem(spacerItem15, 1, 3, 1, 1);


        gridLayout13->addWidget(MultipartAmpEgBox, 1, 0, 1, 1);

        MultipartPitchEgBox = new QGroupBox(MultipartTonePage);
        MultipartPitchEgBox->setObjectName("MultipartPitchEgBox");
        gridLayout17 = new QGridLayout(MultipartPitchEgBox);
        gridLayout17->setSpacing(4);
        gridLayout17->setContentsMargins(4, 4, 4, 4);
        gridLayout17->setObjectName("gridLayout17");
        MultipartPitch = new qxgeditPitch(MultipartPitchEgBox);
        MultipartPitch->setObjectName("MultipartPitch");

        gridLayout17->addWidget(MultipartPitch, 0, 0, 1, 5);

        MultipartAttackLevelDial = new qxgeditDial(MultipartPitchEgBox);
        MultipartAttackLevelDial->setObjectName("MultipartAttackLevelDial");

        gridLayout17->addWidget(MultipartAttackLevelDial, 1, 0, 1, 1);

        MultipartAttackTimeDial = new qxgeditDial(MultipartPitchEgBox);
        MultipartAttackTimeDial->setObjectName("MultipartAttackTimeDial");

        gridLayout17->addWidget(MultipartAttackTimeDial, 1, 1, 1, 1);

        MultipartReleaseLevelDial = new qxgeditDial(MultipartPitchEgBox);
        MultipartReleaseLevelDial->setObjectName("MultipartReleaseLevelDial");

        gridLayout17->addWidget(MultipartReleaseLevelDial, 1, 2, 1, 1);

        MultipartReleaseTimeDial = new qxgeditDial(MultipartPitchEgBox);
        MultipartReleaseTimeDial->setObjectName("MultipartReleaseTimeDial");

        gridLayout17->addWidget(MultipartReleaseTimeDial, 1, 3, 1, 1);

        spacerItem16 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout17->addItem(spacerItem16, 1, 4, 1, 1);


        gridLayout13->addWidget(MultipartPitchEgBox, 1, 1, 1, 1);

        spacerItem17 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout13->addItem(spacerItem17, 2, 0, 1, 2);

        MultipartToolBox->addTab(MultipartTonePage, QString());
        MultipartControlPage = new QWidget();
        MultipartControlPage->setObjectName("MultipartControlPage");
        gridLayout18 = new QGridLayout(MultipartControlPage);
        gridLayout18->setSpacing(4);
        gridLayout18->setContentsMargins(4, 4, 4, 4);
        gridLayout18->setObjectName("gridLayout18");
        MultipartWheelBox = new QGroupBox(MultipartControlPage);
        MultipartWheelBox->setObjectName("MultipartWheelBox");
        gridLayout19 = new QGridLayout(MultipartWheelBox);
        gridLayout19->setSpacing(4);
        gridLayout19->setContentsMargins(4, 4, 4, 4);
        gridLayout19->setObjectName("gridLayout19");
        MultipartWheelPitchDial = new qxgeditDial(MultipartWheelBox);
        MultipartWheelPitchDial->setObjectName("MultipartWheelPitchDial");

        gridLayout19->addWidget(MultipartWheelPitchDial, 0, 0, 1, 1);

        MultipartWheelFilterDial = new qxgeditDial(MultipartWheelBox);
        MultipartWheelFilterDial->setObjectName("MultipartWheelFilterDial");

        gridLayout19->addWidget(MultipartWheelFilterDial, 0, 1, 1, 1);

        MultipartWheelAmplDial = new qxgeditDial(MultipartWheelBox);
        MultipartWheelAmplDial->setObjectName("MultipartWheelAmplDial");

        gridLayout19->addWidget(MultipartWheelAmplDial, 0, 2, 1, 1);

        MultipartWheelLFOPmodDial = new qxgeditDial(MultipartWheelBox);
        MultipartWheelLFOPmodDial->setObjectName("MultipartWheelLFOPmodDial");

        gridLayout19->addWidget(MultipartWheelLFOPmodDial, 1, 0, 1, 1);

        MultipartWheelLFOFmodDial = new qxgeditDial(MultipartWheelBox);
        MultipartWheelLFOFmodDial->setObjectName("MultipartWheelLFOFmodDial");

        gridLayout19->addWidget(MultipartWheelLFOFmodDial, 1, 1, 1, 1);

        MultipartWheelLFOAmodDial = new qxgeditDial(MultipartWheelBox);
        MultipartWheelLFOAmodDial->setObjectName("MultipartWheelLFOAmodDial");

        gridLayout19->addWidget(MultipartWheelLFOAmodDial, 1, 2, 1, 1);


        gridLayout18->addWidget(MultipartWheelBox, 0, 0, 1, 1);

        MultipartBendBox = new QGroupBox(MultipartControlPage);
        MultipartBendBox->setObjectName("MultipartBendBox");
        gridLayout20 = new QGridLayout(MultipartBendBox);
        gridLayout20->setSpacing(4);
        gridLayout20->setContentsMargins(4, 4, 4, 4);
        gridLayout20->setObjectName("gridLayout20");
        MultipartBendPitchDial = new qxgeditDial(MultipartBendBox);
        MultipartBendPitchDial->setObjectName("MultipartBendPitchDial");

        gridLayout20->addWidget(MultipartBendPitchDial, 0, 0, 1, 1);

        MultipartBendFilterDial = new qxgeditDial(MultipartBendBox);
        MultipartBendFilterDial->setObjectName("MultipartBendFilterDial");

        gridLayout20->addWidget(MultipartBendFilterDial, 0, 1, 1, 1);

        MultipartBendAmplDial = new qxgeditDial(MultipartBendBox);
        MultipartBendAmplDial->setObjectName("MultipartBendAmplDial");

        gridLayout20->addWidget(MultipartBendAmplDial, 0, 2, 1, 1);

        MultipartBendLFOPmodDial = new qxgeditDial(MultipartBendBox);
        MultipartBendLFOPmodDial->setObjectName("MultipartBendLFOPmodDial");

        gridLayout20->addWidget(MultipartBendLFOPmodDial, 1, 0, 1, 1);

        MultipartBendLFOFmodDial = new qxgeditDial(MultipartBendBox);
        MultipartBendLFOFmodDial->setObjectName("MultipartBendLFOFmodDial");

        gridLayout20->addWidget(MultipartBendLFOFmodDial, 1, 1, 1, 1);

        MultipartBendLFOAmodDial = new qxgeditDial(MultipartBendBox);
        MultipartBendLFOAmodDial->setObjectName("MultipartBendLFOAmodDial");

        gridLayout20->addWidget(MultipartBendLFOAmodDial, 1, 2, 1, 1);


        gridLayout18->addWidget(MultipartBendBox, 0, 1, 1, 1);

        MultipartCATBox = new QGroupBox(MultipartControlPage);
        MultipartCATBox->setObjectName("MultipartCATBox");
        gridLayout21 = new QGridLayout(MultipartCATBox);
        gridLayout21->setSpacing(4);
        gridLayout21->setContentsMargins(4, 4, 4, 4);
        gridLayout21->setObjectName("gridLayout21");
        MultipartCATPitchDial = new qxgeditDial(MultipartCATBox);
        MultipartCATPitchDial->setObjectName("MultipartCATPitchDial");

        gridLayout21->addWidget(MultipartCATPitchDial, 0, 0, 1, 1);

        MultipartCATFilterDial = new qxgeditDial(MultipartCATBox);
        MultipartCATFilterDial->setObjectName("MultipartCATFilterDial");

        gridLayout21->addWidget(MultipartCATFilterDial, 0, 1, 1, 1);

        MultipartCATAmplDial = new qxgeditDial(MultipartCATBox);
        MultipartCATAmplDial->setObjectName("MultipartCATAmplDial");

        gridLayout21->addWidget(MultipartCATAmplDial, 0, 2, 1, 1);

        MultipartCATLFOPmodDial = new qxgeditDial(MultipartCATBox);
        MultipartCATLFOPmodDial->setObjectName("MultipartCATLFOPmodDial");

        gridLayout21->addWidget(MultipartCATLFOPmodDial, 1, 0, 1, 1);

        MultipartCATLFOFmodDial = new qxgeditDial(MultipartCATBox);
        MultipartCATLFOFmodDial->setObjectName("MultipartCATLFOFmodDial");

        gridLayout21->addWidget(MultipartCATLFOFmodDial, 1, 1, 1, 1);

        MultipartCATLFOAmodDial = new qxgeditDial(MultipartCATBox);
        MultipartCATLFOAmodDial->setObjectName("MultipartCATLFOAmodDial");

        gridLayout21->addWidget(MultipartCATLFOAmodDial, 1, 2, 1, 1);


        gridLayout18->addWidget(MultipartCATBox, 0, 2, 1, 1);

        MultipartPATBox = new QGroupBox(MultipartControlPage);
        MultipartPATBox->setObjectName("MultipartPATBox");
        gridLayout22 = new QGridLayout(MultipartPATBox);
        gridLayout22->setSpacing(4);
        gridLayout22->setContentsMargins(4, 4, 4, 4);
        gridLayout22->setObjectName("gridLayout22");
        MultipartPATPitchDial = new qxgeditDial(MultipartPATBox);
        MultipartPATPitchDial->setObjectName("MultipartPATPitchDial");

        gridLayout22->addWidget(MultipartPATPitchDial, 0, 0, 1, 1);

        MultipartPATFilterDial = new qxgeditDial(MultipartPATBox);
        MultipartPATFilterDial->setObjectName("MultipartPATFilterDial");

        gridLayout22->addWidget(MultipartPATFilterDial, 0, 1, 1, 1);

        MultipartPATAmplDial = new qxgeditDial(MultipartPATBox);
        MultipartPATAmplDial->setObjectName("MultipartPATAmplDial");

        gridLayout22->addWidget(MultipartPATAmplDial, 0, 2, 1, 1);

        MultipartPATLFOPmodDial = new qxgeditDial(MultipartPATBox);
        MultipartPATLFOPmodDial->setObjectName("MultipartPATLFOPmodDial");

        gridLayout22->addWidget(MultipartPATLFOPmodDial, 1, 0, 1, 1);

        MultipartPATLFOFmodDial = new qxgeditDial(MultipartPATBox);
        MultipartPATLFOFmodDial->setObjectName("MultipartPATLFOFmodDial");

        gridLayout22->addWidget(MultipartPATLFOFmodDial, 1, 1, 1, 1);

        MultipartPATLFOAmodDial = new qxgeditDial(MultipartPATBox);
        MultipartPATLFOAmodDial->setObjectName("MultipartPATLFOAmodDial");

        gridLayout22->addWidget(MultipartPATLFOAmodDial, 1, 2, 1, 1);


        gridLayout18->addWidget(MultipartPATBox, 1, 2, 1, 1);

        MultipartTuningBox = new QGroupBox(MultipartControlPage);
        MultipartTuningBox->setObjectName("MultipartTuningBox");
        gridLayout23 = new QGridLayout(MultipartTuningBox);
        gridLayout23->setSpacing(4);
        gridLayout23->setContentsMargins(4, 4, 4, 4);
        gridLayout23->setObjectName("gridLayout23");
        MultipartTuningC_Dial = new qxgeditDial(MultipartTuningBox);
        MultipartTuningC_Dial->setObjectName("MultipartTuningC_Dial");

        gridLayout23->addWidget(MultipartTuningC_Dial, 0, 0, 1, 1);

        MultipartTuningCsDial = new qxgeditDial(MultipartTuningBox);
        MultipartTuningCsDial->setObjectName("MultipartTuningCsDial");

        gridLayout23->addWidget(MultipartTuningCsDial, 0, 1, 1, 1);

        MultipartTuningD_Dial = new qxgeditDial(MultipartTuningBox);
        MultipartTuningD_Dial->setObjectName("MultipartTuningD_Dial");

        gridLayout23->addWidget(MultipartTuningD_Dial, 0, 2, 1, 1);

        MultipartTuningDsDial = new qxgeditDial(MultipartTuningBox);
        MultipartTuningDsDial->setObjectName("MultipartTuningDsDial");

        gridLayout23->addWidget(MultipartTuningDsDial, 0, 3, 1, 1);

        MultipartTuningE_Dial = new qxgeditDial(MultipartTuningBox);
        MultipartTuningE_Dial->setObjectName("MultipartTuningE_Dial");

        gridLayout23->addWidget(MultipartTuningE_Dial, 0, 4, 1, 1);

        MultipartTuningF_Dial = new qxgeditDial(MultipartTuningBox);
        MultipartTuningF_Dial->setObjectName("MultipartTuningF_Dial");

        gridLayout23->addWidget(MultipartTuningF_Dial, 0, 5, 1, 1);

        MultipartTuningFsDial = new qxgeditDial(MultipartTuningBox);
        MultipartTuningFsDial->setObjectName("MultipartTuningFsDial");

        gridLayout23->addWidget(MultipartTuningFsDial, 1, 0, 1, 1);

        MultipartTuningG_Dial = new qxgeditDial(MultipartTuningBox);
        MultipartTuningG_Dial->setObjectName("MultipartTuningG_Dial");

        gridLayout23->addWidget(MultipartTuningG_Dial, 1, 1, 1, 1);

        MultipartTuningGsDial = new qxgeditDial(MultipartTuningBox);
        MultipartTuningGsDial->setObjectName("MultipartTuningGsDial");

        gridLayout23->addWidget(MultipartTuningGsDial, 1, 2, 1, 1);

        MultipartTuningA_Dial = new qxgeditDial(MultipartTuningBox);
        MultipartTuningA_Dial->setObjectName("MultipartTuningA_Dial");

        gridLayout23->addWidget(MultipartTuningA_Dial, 1, 3, 1, 1);

        MultipartTuningAsDial = new qxgeditDial(MultipartTuningBox);
        MultipartTuningAsDial->setObjectName("MultipartTuningAsDial");

        gridLayout23->addWidget(MultipartTuningAsDial, 1, 4, 1, 1);

        MultipartTuningB_Dial = new qxgeditDial(MultipartTuningBox);
        MultipartTuningB_Dial->setObjectName("MultipartTuningB_Dial");

        gridLayout23->addWidget(MultipartTuningB_Dial, 1, 5, 1, 1);


        gridLayout18->addWidget(MultipartTuningBox, 1, 0, 1, 2);

        spacerItem18 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout18->addItem(spacerItem18, 2, 0, 1, 3);

        MultipartToolBox->addTab(MultipartControlPage, QString());
        MultipartOptionsPage = new QWidget();
        MultipartOptionsPage->setObjectName("MultipartOptionsPage");
        gridLayout24 = new QGridLayout(MultipartOptionsPage);
        gridLayout24->setSpacing(4);
        gridLayout24->setContentsMargins(4, 4, 4, 4);
        gridLayout24->setObjectName("gridLayout24");
        MultipartAC1Box = new QGroupBox(MultipartOptionsPage);
        MultipartAC1Box->setObjectName("MultipartAC1Box");
        gridLayout25 = new QGridLayout(MultipartAC1Box);
        gridLayout25->setSpacing(4);
        gridLayout25->setContentsMargins(4, 4, 4, 4);
        gridLayout25->setObjectName("gridLayout25");
        MultipartAC1ControlDial = new qxgeditDial(MultipartAC1Box);
        MultipartAC1ControlDial->setObjectName("MultipartAC1ControlDial");

        gridLayout25->addWidget(MultipartAC1ControlDial, 0, 0, 1, 1);

        MultipartAC1PitchDial = new qxgeditDial(MultipartAC1Box);
        MultipartAC1PitchDial->setObjectName("MultipartAC1PitchDial");

        gridLayout25->addWidget(MultipartAC1PitchDial, 0, 1, 1, 1);

        MultipartAC1FilterDial = new qxgeditDial(MultipartAC1Box);
        MultipartAC1FilterDial->setObjectName("MultipartAC1FilterDial");

        gridLayout25->addWidget(MultipartAC1FilterDial, 0, 2, 1, 1);

        MultipartAC1AmplDial = new qxgeditDial(MultipartAC1Box);
        MultipartAC1AmplDial->setObjectName("MultipartAC1AmplDial");

        gridLayout25->addWidget(MultipartAC1AmplDial, 0, 3, 1, 1);

        MultipartAC1LFOPmodDial = new qxgeditDial(MultipartAC1Box);
        MultipartAC1LFOPmodDial->setObjectName("MultipartAC1LFOPmodDial");

        gridLayout25->addWidget(MultipartAC1LFOPmodDial, 0, 4, 1, 1);

        MultipartAC1LFOFmodDial = new qxgeditDial(MultipartAC1Box);
        MultipartAC1LFOFmodDial->setObjectName("MultipartAC1LFOFmodDial");

        gridLayout25->addWidget(MultipartAC1LFOFmodDial, 0, 5, 1, 1);

        MultipartAC1LFOAmodDial = new qxgeditDial(MultipartAC1Box);
        MultipartAC1LFOAmodDial->setObjectName("MultipartAC1LFOAmodDial");

        gridLayout25->addWidget(MultipartAC1LFOAmodDial, 0, 6, 1, 1);


        gridLayout24->addWidget(MultipartAC1Box, 0, 0, 1, 1);

        MultipartAC2Box = new QGroupBox(MultipartOptionsPage);
        MultipartAC2Box->setObjectName("MultipartAC2Box");
        gridLayout26 = new QGridLayout(MultipartAC2Box);
        gridLayout26->setSpacing(4);
        gridLayout26->setContentsMargins(4, 4, 4, 4);
        gridLayout26->setObjectName("gridLayout26");
        MultipartAC2ControlDial = new qxgeditDial(MultipartAC2Box);
        MultipartAC2ControlDial->setObjectName("MultipartAC2ControlDial");

        gridLayout26->addWidget(MultipartAC2ControlDial, 0, 0, 1, 1);

        MultipartAC2PitchDial = new qxgeditDial(MultipartAC2Box);
        MultipartAC2PitchDial->setObjectName("MultipartAC2PitchDial");

        gridLayout26->addWidget(MultipartAC2PitchDial, 0, 1, 1, 1);

        MultipartAC2FilterDial = new qxgeditDial(MultipartAC2Box);
        MultipartAC2FilterDial->setObjectName("MultipartAC2FilterDial");

        gridLayout26->addWidget(MultipartAC2FilterDial, 0, 2, 1, 1);

        MultipartAC2AmplDial = new qxgeditDial(MultipartAC2Box);
        MultipartAC2AmplDial->setObjectName("MultipartAC2AmplDial");

        gridLayout26->addWidget(MultipartAC2AmplDial, 0, 3, 1, 1);

        MultipartAC2LFOPmodDial = new qxgeditDial(MultipartAC2Box);
        MultipartAC2LFOPmodDial->setObjectName("MultipartAC2LFOPmodDial");

        gridLayout26->addWidget(MultipartAC2LFOPmodDial, 0, 4, 1, 1);

        MultipartAC2LFOFmodDial = new qxgeditDial(MultipartAC2Box);
        MultipartAC2LFOFmodDial->setObjectName("MultipartAC2LFOFmodDial");

        gridLayout26->addWidget(MultipartAC2LFOFmodDial, 0, 5, 1, 1);

        MultipartAC2LFOAmodDial = new qxgeditDial(MultipartAC2Box);
        MultipartAC2LFOAmodDial->setObjectName("MultipartAC2LFOAmodDial");

        gridLayout26->addWidget(MultipartAC2LFOAmodDial, 0, 6, 1, 1);


        gridLayout24->addWidget(MultipartAC2Box, 1, 0, 1, 1);

        MultipartReceiveBox = new QGroupBox(MultipartOptionsPage);
        MultipartReceiveBox->setObjectName("MultipartReceiveBox");
        gridLayout27 = new QGridLayout(MultipartReceiveBox);
        gridLayout27->setSpacing(4);
        gridLayout27->setContentsMargins(4, 4, 4, 4);
        gridLayout27->setObjectName("gridLayout27");
        MultipartPBCheck = new qxgeditCheck(MultipartReceiveBox);
        MultipartPBCheck->setObjectName("MultipartPBCheck");

        gridLayout27->addWidget(MultipartPBCheck, 0, 0, 1, 1);

        MultipartCATCheck = new qxgeditCheck(MultipartReceiveBox);
        MultipartCATCheck->setObjectName("MultipartCATCheck");

        gridLayout27->addWidget(MultipartCATCheck, 0, 1, 1, 1);

        MultipartPCCheck = new qxgeditCheck(MultipartReceiveBox);
        MultipartPCCheck->setObjectName("MultipartPCCheck");

        gridLayout27->addWidget(MultipartPCCheck, 0, 2, 1, 1);

        MultipartCCCheck = new qxgeditCheck(MultipartReceiveBox);
        MultipartCCCheck->setObjectName("MultipartCCCheck");

        gridLayout27->addWidget(MultipartCCCheck, 0, 3, 1, 1);

        MultipartPATCheck = new qxgeditCheck(MultipartReceiveBox);
        MultipartPATCheck->setObjectName("MultipartPATCheck");

        gridLayout27->addWidget(MultipartPATCheck, 0, 4, 1, 1);

        MultipartNoteCheck = new qxgeditCheck(MultipartReceiveBox);
        MultipartNoteCheck->setObjectName("MultipartNoteCheck");

        gridLayout27->addWidget(MultipartNoteCheck, 0, 5, 1, 1);

        MultipartRPNCheck = new qxgeditCheck(MultipartReceiveBox);
        MultipartRPNCheck->setObjectName("MultipartRPNCheck");

        gridLayout27->addWidget(MultipartRPNCheck, 0, 6, 1, 1);

        MultipartNRPNCheck = new qxgeditCheck(MultipartReceiveBox);
        MultipartNRPNCheck->setObjectName("MultipartNRPNCheck");

        gridLayout27->addWidget(MultipartNRPNCheck, 0, 7, 1, 1);

        MultipartModCheck = new qxgeditCheck(MultipartReceiveBox);
        MultipartModCheck->setObjectName("MultipartModCheck");

        gridLayout27->addWidget(MultipartModCheck, 0, 8, 1, 1);

        MultipartVolCheck = new qxgeditCheck(MultipartReceiveBox);
        MultipartVolCheck->setObjectName("MultipartVolCheck");

        gridLayout27->addWidget(MultipartVolCheck, 1, 0, 1, 1);

        MultipartPanCheck = new qxgeditCheck(MultipartReceiveBox);
        MultipartPanCheck->setObjectName("MultipartPanCheck");

        gridLayout27->addWidget(MultipartPanCheck, 1, 1, 1, 1);

        MultipartExprCheck = new qxgeditCheck(MultipartReceiveBox);
        MultipartExprCheck->setObjectName("MultipartExprCheck");

        gridLayout27->addWidget(MultipartExprCheck, 1, 2, 1, 1);

        MultipartHold1Check = new qxgeditCheck(MultipartReceiveBox);
        MultipartHold1Check->setObjectName("MultipartHold1Check");

        gridLayout27->addWidget(MultipartHold1Check, 1, 3, 1, 1);

        MultipartPortaCheck = new qxgeditCheck(MultipartReceiveBox);
        MultipartPortaCheck->setObjectName("MultipartPortaCheck");

        gridLayout27->addWidget(MultipartPortaCheck, 1, 4, 1, 1);

        MultipartSostCheck = new qxgeditCheck(MultipartReceiveBox);
        MultipartSostCheck->setObjectName("MultipartSostCheck");

        gridLayout27->addWidget(MultipartSostCheck, 1, 5, 1, 1);

        MultipartPedalCheck = new qxgeditCheck(MultipartReceiveBox);
        MultipartPedalCheck->setObjectName("MultipartPedalCheck");

        gridLayout27->addWidget(MultipartPedalCheck, 1, 6, 1, 1);

        MultipartBankCheck = new qxgeditCheck(MultipartReceiveBox);
        MultipartBankCheck->setObjectName("MultipartBankCheck");

        gridLayout27->addWidget(MultipartBankCheck, 1, 7, 1, 1);


        gridLayout24->addWidget(MultipartReceiveBox, 2, 0, 1, 1);

        spacerItem19 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout24->addItem(spacerItem19, 3, 0, 1, 1);

        MultipartToolBox->addTab(MultipartOptionsPage, QString());

        vboxLayout2->addWidget(MultipartToolBox);

        MainTabWidget->addTab(MultipartTab, QString());
        DrumsetupTab = new QWidget();
        DrumsetupTab->setObjectName("DrumsetupTab");
        vboxLayout3 = new QVBoxLayout(DrumsetupTab);
        vboxLayout3->setSpacing(4);
        vboxLayout3->setContentsMargins(4, 4, 4, 4);
        vboxLayout3->setObjectName("vboxLayout3");
        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(4);
        hboxLayout1->setObjectName("hboxLayout1");
        DrumsetupResetButton = new QPushButton(DrumsetupTab);
        DrumsetupResetButton->setObjectName("DrumsetupResetButton");

        hboxLayout1->addWidget(DrumsetupResetButton);

        DrumsetupCombo = new QComboBox(DrumsetupTab);
        DrumsetupCombo->setObjectName("DrumsetupCombo");

        hboxLayout1->addWidget(DrumsetupCombo);

        DrumsetupVoiceCombo = new QComboBox(DrumsetupTab);
        DrumsetupVoiceCombo->setObjectName("DrumsetupVoiceCombo");

        hboxLayout1->addWidget(DrumsetupVoiceCombo);

        DrumsetupNoteCombo = new QComboBox(DrumsetupTab);
        DrumsetupNoteCombo->setObjectName("DrumsetupNoteCombo");

        hboxLayout1->addWidget(DrumsetupNoteCombo);

        spacerItem20 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem20);


        vboxLayout3->addLayout(hboxLayout1);

        gridLayout28 = new QGridLayout();
        gridLayout28->setSpacing(4);
        gridLayout28->setObjectName("gridLayout28");
        DrumsetupPitchBox = new QGroupBox(DrumsetupTab);
        DrumsetupPitchBox->setObjectName("DrumsetupPitchBox");
        gridLayout29 = new QGridLayout(DrumsetupPitchBox);
        gridLayout29->setSpacing(4);
        gridLayout29->setContentsMargins(4, 4, 4, 4);
        gridLayout29->setObjectName("gridLayout29");
        DrumsetupCoarseDial = new qxgeditDial(DrumsetupPitchBox);
        DrumsetupCoarseDial->setObjectName("DrumsetupCoarseDial");

        gridLayout29->addWidget(DrumsetupCoarseDial, 0, 0, 1, 1);

        DrumsetupFineDial = new qxgeditDial(DrumsetupPitchBox);
        DrumsetupFineDial->setObjectName("DrumsetupFineDial");

        gridLayout29->addWidget(DrumsetupFineDial, 0, 1, 1, 1);


        gridLayout28->addWidget(DrumsetupPitchBox, 0, 0, 1, 2);

        DrumsetupControlBox = new QGroupBox(DrumsetupTab);
        DrumsetupControlBox->setObjectName("DrumsetupControlBox");
        gridLayout30 = new QGridLayout(DrumsetupControlBox);
        gridLayout30->setSpacing(4);
        gridLayout30->setContentsMargins(4, 4, 4, 4);
        gridLayout30->setObjectName("gridLayout30");
        DrumsetupLevelDial = new qxgeditDial(DrumsetupControlBox);
        DrumsetupLevelDial->setObjectName("DrumsetupLevelDial");

        gridLayout30->addWidget(DrumsetupLevelDial, 0, 0, 1, 1);

        DrumsetupPanDial = new qxgeditDial(DrumsetupControlBox);
        DrumsetupPanDial->setObjectName("DrumsetupPanDial");

        gridLayout30->addWidget(DrumsetupPanDial, 0, 1, 1, 1);


        gridLayout28->addWidget(DrumsetupControlBox, 0, 2, 1, 2);

        DrumsetupModeBox = new QGroupBox(DrumsetupTab);
        DrumsetupModeBox->setObjectName("DrumsetupModeBox");
        gridLayout31 = new QGridLayout(DrumsetupModeBox);
        gridLayout31->setSpacing(4);
        gridLayout31->setContentsMargins(4, 4, 4, 4);
        gridLayout31->setObjectName("gridLayout31");
        DrumsetupGroupDial = new qxgeditDial(DrumsetupModeBox);
        DrumsetupGroupDial->setObjectName("DrumsetupGroupDial");

        gridLayout31->addWidget(DrumsetupGroupDial, 0, 0, 1, 1);

        DrumsetupKeyAssignDial = new qxgeditDial(DrumsetupModeBox);
        DrumsetupKeyAssignDial->setObjectName("DrumsetupKeyAssignDial");

        gridLayout31->addWidget(DrumsetupKeyAssignDial, 0, 1, 1, 1);


        gridLayout28->addWidget(DrumsetupModeBox, 0, 4, 1, 2);

        DrumsetupEffectBox = new QGroupBox(DrumsetupTab);
        DrumsetupEffectBox->setObjectName("DrumsetupEffectBox");
        gridLayout32 = new QGridLayout(DrumsetupEffectBox);
        gridLayout32->setSpacing(4);
        gridLayout32->setContentsMargins(4, 4, 4, 4);
        gridLayout32->setObjectName("gridLayout32");
        DrumsetupReverbDial = new qxgeditDial(DrumsetupEffectBox);
        DrumsetupReverbDial->setObjectName("DrumsetupReverbDial");

        gridLayout32->addWidget(DrumsetupReverbDial, 0, 0, 1, 1);

        DrumsetupChorusDial = new qxgeditDial(DrumsetupEffectBox);
        DrumsetupChorusDial->setObjectName("DrumsetupChorusDial");

        gridLayout32->addWidget(DrumsetupChorusDial, 0, 1, 1, 1);

        DrumsetupVariationDial = new qxgeditDial(DrumsetupEffectBox);
        DrumsetupVariationDial->setObjectName("DrumsetupVariationDial");

        gridLayout32->addWidget(DrumsetupVariationDial, 0, 2, 1, 1);


        gridLayout28->addWidget(DrumsetupEffectBox, 0, 6, 1, 3);

        DrumsetupFilterBox = new QGroupBox(DrumsetupTab);
        DrumsetupFilterBox->setObjectName("DrumsetupFilterBox");
        gridLayout33 = new QGridLayout(DrumsetupFilterBox);
        gridLayout33->setSpacing(4);
        gridLayout33->setContentsMargins(4, 4, 4, 4);
        gridLayout33->setObjectName("gridLayout33");
        DrumsetupFilter = new qxgeditFilter(DrumsetupFilterBox);
        DrumsetupFilter->setObjectName("DrumsetupFilter");

        gridLayout33->addWidget(DrumsetupFilter, 0, 0, 1, 3);

        DrumsetupCutoffDial = new qxgeditDial(DrumsetupFilterBox);
        DrumsetupCutoffDial->setObjectName("DrumsetupCutoffDial");

        gridLayout33->addWidget(DrumsetupCutoffDial, 1, 0, 1, 1);

        DrumsetupResonanceDial = new qxgeditDial(DrumsetupFilterBox);
        DrumsetupResonanceDial->setObjectName("DrumsetupResonanceDial");

        gridLayout33->addWidget(DrumsetupResonanceDial, 1, 1, 1, 1);


        gridLayout28->addWidget(DrumsetupFilterBox, 1, 0, 1, 3);

        DrumsetupAmpEgBox = new QGroupBox(DrumsetupTab);
        DrumsetupAmpEgBox->setObjectName("DrumsetupAmpEgBox");
        gridLayout34 = new QGridLayout(DrumsetupAmpEgBox);
        gridLayout34->setSpacing(4);
        gridLayout34->setContentsMargins(4, 4, 4, 4);
        gridLayout34->setObjectName("gridLayout34");
        DrumsetupAmpEg = new qxgeditDrumEg(DrumsetupAmpEgBox);
        DrumsetupAmpEg->setObjectName("DrumsetupAmpEg");

        gridLayout34->addWidget(DrumsetupAmpEg, 0, 0, 1, 3);

        DrumsetupAttackDial = new qxgeditDial(DrumsetupAmpEgBox);
        DrumsetupAttackDial->setObjectName("DrumsetupAttackDial");

        gridLayout34->addWidget(DrumsetupAttackDial, 1, 0, 1, 1);

        DrumsetupDecay1Dial = new qxgeditDial(DrumsetupAmpEgBox);
        DrumsetupDecay1Dial->setObjectName("DrumsetupDecay1Dial");

        gridLayout34->addWidget(DrumsetupDecay1Dial, 1, 1, 1, 1);

        DrumsetupDecay2Dial = new qxgeditDial(DrumsetupAmpEgBox);
        DrumsetupDecay2Dial->setObjectName("DrumsetupDecay2Dial");

        gridLayout34->addWidget(DrumsetupDecay2Dial, 1, 2, 1, 1);


        gridLayout28->addWidget(DrumsetupAmpEgBox, 1, 3, 1, 3);

        DrumsetupNoteBox = new QGroupBox(DrumsetupTab);
        DrumsetupNoteBox->setObjectName("DrumsetupNoteBox");
        gridLayout35 = new QGridLayout(DrumsetupNoteBox);
        gridLayout35->setSpacing(4);
        gridLayout35->setContentsMargins(4, 4, 4, 4);
        gridLayout35->setObjectName("gridLayout35");
        DrumsetupNoteOnCheck = new qxgeditCheck(DrumsetupNoteBox);
        DrumsetupNoteOnCheck->setObjectName("DrumsetupNoteOnCheck");

        gridLayout35->addWidget(DrumsetupNoteOnCheck, 0, 0, 1, 1);

        DrumsetupNoteOffCheck = new qxgeditCheck(DrumsetupNoteBox);
        DrumsetupNoteOffCheck->setObjectName("DrumsetupNoteOffCheck");

        gridLayout35->addWidget(DrumsetupNoteOffCheck, 0, 1, 1, 1);

        spacerItem21 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout35->addItem(spacerItem21, 1, 0, 1, 2);


        gridLayout28->addWidget(DrumsetupNoteBox, 1, 6, 1, 3);

        spacerItem22 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout28->addItem(spacerItem22, 2, 0, 1, 9);


        vboxLayout3->addLayout(gridLayout28);

        MainTabWidget->addTab(DrumsetupTab, QString());
        UservoiceTab = new QWidget();
        UservoiceTab->setObjectName("UservoiceTab");
        vboxLayout4 = new QVBoxLayout(UservoiceTab);
        vboxLayout4->setSpacing(4);
        vboxLayout4->setContentsMargins(4, 4, 4, 4);
        vboxLayout4->setObjectName("vboxLayout4");
        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(4);
        hboxLayout2->setObjectName("hboxLayout2");
        UservoiceResetButton = new QPushButton(UservoiceTab);
        UservoiceResetButton->setObjectName("UservoiceResetButton");

        hboxLayout2->addWidget(UservoiceResetButton);

        UservoiceCombo = new QComboBox(UservoiceTab);
        UservoiceCombo->setObjectName("UservoiceCombo");

        hboxLayout2->addWidget(UservoiceCombo);

        UservoiceNameEdit = new qxgeditEdit(UservoiceTab);
        UservoiceNameEdit->setObjectName("UservoiceNameEdit");

        hboxLayout2->addWidget(UservoiceNameEdit);

        UservoiceElementCombo = new QComboBox(UservoiceTab);
        UservoiceElementCombo->setObjectName("UservoiceElementCombo");

        hboxLayout2->addWidget(UservoiceElementCombo);

        spacerItem23 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem23);

        UservoiceAutoSendCheck = new QCheckBox(UservoiceTab);
        UservoiceAutoSendCheck->setObjectName("UservoiceAutoSendCheck");

        hboxLayout2->addWidget(UservoiceAutoSendCheck);

        UservoiceSendButton = new QPushButton(UservoiceTab);
        UservoiceSendButton->setObjectName("UservoiceSendButton");

        hboxLayout2->addWidget(UservoiceSendButton);


        vboxLayout4->addLayout(hboxLayout2);

        UservoiceToolBox = new QTabWidget(UservoiceTab);
        UservoiceToolBox->setObjectName("UservoiceToolBox");
        UservoiceMainPage = new QWidget();
        UservoiceMainPage->setObjectName("UservoiceMainPage");
        gridLayout36 = new QGridLayout(UservoiceMainPage);
        gridLayout36->setSpacing(4);
        gridLayout36->setContentsMargins(4, 4, 4, 4);
        gridLayout36->setObjectName("gridLayout36");
        UservoiceCommonBox = new QGroupBox(UservoiceMainPage);
        UservoiceCommonBox->setObjectName("UservoiceCommonBox");
        gridLayout37 = new QGridLayout(UservoiceCommonBox);
        gridLayout37->setSpacing(4);
        gridLayout37->setContentsMargins(4, 4, 4, 4);
        gridLayout37->setObjectName("gridLayout37");
        UservoiceLevelDial = new qxgeditDial(UservoiceCommonBox);
        UservoiceLevelDial->setObjectName("UservoiceLevelDial");

        gridLayout37->addWidget(UservoiceLevelDial, 0, 0, 1, 1);

        UservoiceElementDial = new qxgeditDial(UservoiceCommonBox);
        UservoiceElementDial->setObjectName("UservoiceElementDial");

        gridLayout37->addWidget(UservoiceElementDial, 0, 1, 1, 1);


        gridLayout36->addWidget(UservoiceCommonBox, 0, 0, 1, 2);

        UservoiceElementBox = new QGroupBox(UservoiceMainPage);
        UservoiceElementBox->setObjectName("UservoiceElementBox");
        gridLayout38 = new QGridLayout(UservoiceElementBox);
        gridLayout38->setSpacing(4);
        gridLayout38->setContentsMargins(4, 4, 4, 4);
        gridLayout38->setObjectName("gridLayout38");
        UservoiceWaveDial = new qxgeditDial(UservoiceElementBox);
        UservoiceWaveDial->setObjectName("UservoiceWaveDial");

        gridLayout38->addWidget(UservoiceWaveDial, 0, 0, 1, 1);

        UservoiceNoteLowDial = new qxgeditDial(UservoiceElementBox);
        UservoiceNoteLowDial->setObjectName("UservoiceNoteLowDial");

        gridLayout38->addWidget(UservoiceNoteLowDial, 0, 1, 1, 1);

        UservoiceNoteHighDial = new qxgeditDial(UservoiceElementBox);
        UservoiceNoteHighDial->setObjectName("UservoiceNoteHighDial");

        gridLayout38->addWidget(UservoiceNoteHighDial, 0, 2, 1, 1);

        UservoiceVelLowDial = new qxgeditDial(UservoiceElementBox);
        UservoiceVelLowDial->setObjectName("UservoiceVelLowDial");

        gridLayout38->addWidget(UservoiceVelLowDial, 0, 3, 1, 1);

        UservoiceVelHighDial = new qxgeditDial(UservoiceElementBox);
        UservoiceVelHighDial->setObjectName("UservoiceVelHighDial");

        gridLayout38->addWidget(UservoiceVelHighDial, 0, 4, 1, 1);

        UservoiceFEGVelCurveDial = new qxgeditDial(UservoiceElementBox);
        UservoiceFEGVelCurveDial->setObjectName("UservoiceFEGVelCurveDial");

        gridLayout38->addWidget(UservoiceFEGVelCurveDial, 0, 5, 1, 1);


        gridLayout36->addWidget(UservoiceElementBox, 0, 2, 1, 6);

        UservoiceLFOBox = new QGroupBox(UservoiceMainPage);
        UservoiceLFOBox->setObjectName("UservoiceLFOBox");
        gridLayout39 = new QGridLayout(UservoiceLFOBox);
        gridLayout39->setSpacing(4);
        gridLayout39->setContentsMargins(4, 4, 4, 4);
        gridLayout39->setObjectName("gridLayout39");
        UservoiceLFOWaveDial = new qxgeditDial(UservoiceLFOBox);
        UservoiceLFOWaveDial->setObjectName("UservoiceLFOWaveDial");

        gridLayout39->addWidget(UservoiceLFOWaveDial, 0, 0, 1, 1);

        UservoiceLFOPhaseDial = new qxgeditDial(UservoiceLFOBox);
        UservoiceLFOPhaseDial->setObjectName("UservoiceLFOPhaseDial");

        gridLayout39->addWidget(UservoiceLFOPhaseDial, 0, 1, 1, 1);

        UservoiceLFOSpeedDial = new qxgeditDial(UservoiceLFOBox);
        UservoiceLFOSpeedDial->setObjectName("UservoiceLFOSpeedDial");

        gridLayout39->addWidget(UservoiceLFOSpeedDial, 0, 2, 1, 1);

        UservoiceLFODelayDial = new qxgeditDial(UservoiceLFOBox);
        UservoiceLFODelayDial->setObjectName("UservoiceLFODelayDial");

        gridLayout39->addWidget(UservoiceLFODelayDial, 0, 3, 1, 1);

        UservoiceLFOFadeDial = new qxgeditDial(UservoiceLFOBox);
        UservoiceLFOFadeDial->setObjectName("UservoiceLFOFadeDial");

        gridLayout39->addWidget(UservoiceLFOFadeDial, 0, 4, 1, 1);

        UservoiceLFOPitchDial = new qxgeditDial(UservoiceLFOBox);
        UservoiceLFOPitchDial->setObjectName("UservoiceLFOPitchDial");

        gridLayout39->addWidget(UservoiceLFOPitchDial, 0, 5, 1, 1);

        UservoiceLFOCutoffDial = new qxgeditDial(UservoiceLFOBox);
        UservoiceLFOCutoffDial->setObjectName("UservoiceLFOCutoffDial");

        gridLayout39->addWidget(UservoiceLFOCutoffDial, 0, 6, 1, 1);

        UservoiceLFOAmplDial = new qxgeditDial(UservoiceLFOBox);
        UservoiceLFOAmplDial->setObjectName("UservoiceLFOAmplDial");

        gridLayout39->addWidget(UservoiceLFOAmplDial, 0, 7, 1, 1);


        gridLayout36->addWidget(UservoiceLFOBox, 1, 0, 1, 8);

        spacerItem24 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout36->addItem(spacerItem24, 2, 0, 1, 8);

        UservoiceToolBox->addTab(UservoiceMainPage, QString());
        UservoiceLevelPage = new QWidget();
        UservoiceLevelPage->setObjectName("UservoiceLevelPage");
        gridLayout40 = new QGridLayout(UservoiceLevelPage);
        gridLayout40->setSpacing(4);
        gridLayout40->setContentsMargins(4, 4, 4, 4);
        gridLayout40->setObjectName("gridLayout40");
        UservoiceLevelScaleBox = new QGroupBox(UservoiceLevelPage);
        UservoiceLevelScaleBox->setObjectName("UservoiceLevelScaleBox");
        gridLayout41 = new QGridLayout(UservoiceLevelScaleBox);
        gridLayout41->setSpacing(4);
        gridLayout41->setContentsMargins(4, 4, 4, 4);
        gridLayout41->setObjectName("gridLayout41");
        UservoiceLevelScale = new qxgeditScale(UservoiceLevelScaleBox);
        UservoiceLevelScale->setObjectName("UservoiceLevelScale");

        gridLayout41->addWidget(UservoiceLevelScale, 0, 0, 1, 4);

        UservoiceLevelBreak1Dial = new qxgeditDial(UservoiceLevelScaleBox);
        UservoiceLevelBreak1Dial->setObjectName("UservoiceLevelBreak1Dial");

        gridLayout41->addWidget(UservoiceLevelBreak1Dial, 1, 0, 1, 1);

        UservoiceLevelBreak2Dial = new qxgeditDial(UservoiceLevelScaleBox);
        UservoiceLevelBreak2Dial->setObjectName("UservoiceLevelBreak2Dial");

        gridLayout41->addWidget(UservoiceLevelBreak2Dial, 1, 1, 1, 1);

        UservoiceLevelBreak3Dial = new qxgeditDial(UservoiceLevelScaleBox);
        UservoiceLevelBreak3Dial->setObjectName("UservoiceLevelBreak3Dial");

        gridLayout41->addWidget(UservoiceLevelBreak3Dial, 1, 2, 1, 1);

        UservoiceLevelBreak4Dial = new qxgeditDial(UservoiceLevelScaleBox);
        UservoiceLevelBreak4Dial->setObjectName("UservoiceLevelBreak4Dial");

        gridLayout41->addWidget(UservoiceLevelBreak4Dial, 1, 3, 1, 1);

        UservoiceLevelOffset1Dial = new qxgeditDial(UservoiceLevelScaleBox);
        UservoiceLevelOffset1Dial->setObjectName("UservoiceLevelOffset1Dial");

        gridLayout41->addWidget(UservoiceLevelOffset1Dial, 2, 0, 1, 1);

        UservoiceLevelOffset2Dial = new qxgeditDial(UservoiceLevelScaleBox);
        UservoiceLevelOffset2Dial->setObjectName("UservoiceLevelOffset2Dial");

        gridLayout41->addWidget(UservoiceLevelOffset2Dial, 2, 1, 1, 1);

        UservoiceLevelOffset3Dial = new qxgeditDial(UservoiceLevelScaleBox);
        UservoiceLevelOffset3Dial->setObjectName("UservoiceLevelOffset3Dial");

        gridLayout41->addWidget(UservoiceLevelOffset3Dial, 2, 2, 1, 1);

        UservoiceLevelOffset4Dial = new qxgeditDial(UservoiceLevelScaleBox);
        UservoiceLevelOffset4Dial->setObjectName("UservoiceLevelOffset4Dial");

        gridLayout41->addWidget(UservoiceLevelOffset4Dial, 2, 3, 1, 1);


        gridLayout40->addWidget(UservoiceLevelScaleBox, 0, 0, 1, 4);

        UservoiceLevelParamBox = new QGroupBox(UservoiceLevelPage);
        UservoiceLevelParamBox->setObjectName("UservoiceLevelParamBox");
        gridLayout42 = new QGridLayout(UservoiceLevelParamBox);
        gridLayout42->setSpacing(4);
        gridLayout42->setContentsMargins(4, 4, 4, 4);
        gridLayout42->setObjectName("gridLayout42");
        UservoiceElementLevelDial = new qxgeditDial(UservoiceLevelParamBox);
        UservoiceElementLevelDial->setObjectName("UservoiceElementLevelDial");

        gridLayout42->addWidget(UservoiceElementLevelDial, 0, 0, 1, 1);

        UservoiceVelCurveDial = new qxgeditDial(UservoiceLevelParamBox);
        UservoiceVelCurveDial->setObjectName("UservoiceVelCurveDial");

        gridLayout42->addWidget(UservoiceVelCurveDial, 0, 1, 1, 1);

        UservoicePanDial = new qxgeditDial(UservoiceLevelParamBox);
        UservoicePanDial->setObjectName("UservoicePanDial");

        gridLayout42->addWidget(UservoicePanDial, 0, 2, 1, 1);

        spacerItem25 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout42->addItem(spacerItem25, 1, 0, 1, 3);


        gridLayout40->addWidget(UservoiceLevelParamBox, 0, 4, 1, 5);

        spacerItem26 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout40->addItem(spacerItem26, 1, 0, 1, 9);

        UservoiceToolBox->addTab(UservoiceLevelPage, QString());
        UservoiceCutoffPage = new QWidget();
        UservoiceCutoffPage->setObjectName("UservoiceCutoffPage");
        gridLayout43 = new QGridLayout(UservoiceCutoffPage);
        gridLayout43->setSpacing(4);
        gridLayout43->setContentsMargins(4, 4, 4, 4);
        gridLayout43->setObjectName("gridLayout43");
        UservoiceCutoffScaleBox = new QGroupBox(UservoiceCutoffPage);
        UservoiceCutoffScaleBox->setObjectName("UservoiceCutoffScaleBox");
        gridLayout44 = new QGridLayout(UservoiceCutoffScaleBox);
        gridLayout44->setSpacing(4);
        gridLayout44->setContentsMargins(4, 4, 4, 4);
        gridLayout44->setObjectName("gridLayout44");
        UservoiceCutoffScale = new qxgeditScale(UservoiceCutoffScaleBox);
        UservoiceCutoffScale->setObjectName("UservoiceCutoffScale");

        gridLayout44->addWidget(UservoiceCutoffScale, 0, 0, 1, 4);

        UservoiceCutoffBreak1Dial = new qxgeditDial(UservoiceCutoffScaleBox);
        UservoiceCutoffBreak1Dial->setObjectName("UservoiceCutoffBreak1Dial");

        gridLayout44->addWidget(UservoiceCutoffBreak1Dial, 1, 0, 1, 1);

        UservoiceCutoffBreak2Dial = new qxgeditDial(UservoiceCutoffScaleBox);
        UservoiceCutoffBreak2Dial->setObjectName("UservoiceCutoffBreak2Dial");

        gridLayout44->addWidget(UservoiceCutoffBreak2Dial, 1, 1, 1, 1);

        UservoiceCutoffBreak3Dial = new qxgeditDial(UservoiceCutoffScaleBox);
        UservoiceCutoffBreak3Dial->setObjectName("UservoiceCutoffBreak3Dial");

        gridLayout44->addWidget(UservoiceCutoffBreak3Dial, 1, 2, 1, 1);

        UservoiceCutoffBreak4Dial = new qxgeditDial(UservoiceCutoffScaleBox);
        UservoiceCutoffBreak4Dial->setObjectName("UservoiceCutoffBreak4Dial");

        gridLayout44->addWidget(UservoiceCutoffBreak4Dial, 1, 3, 1, 1);

        UservoiceCutoffOffset1Dial = new qxgeditDial(UservoiceCutoffScaleBox);
        UservoiceCutoffOffset1Dial->setObjectName("UservoiceCutoffOffset1Dial");

        gridLayout44->addWidget(UservoiceCutoffOffset1Dial, 2, 0, 1, 1);

        UservoiceCutoffOffset2Dial = new qxgeditDial(UservoiceCutoffScaleBox);
        UservoiceCutoffOffset2Dial->setObjectName("UservoiceCutoffOffset2Dial");

        gridLayout44->addWidget(UservoiceCutoffOffset2Dial, 2, 1, 1, 1);

        UservoiceCutoffOffset3Dial = new qxgeditDial(UservoiceCutoffScaleBox);
        UservoiceCutoffOffset3Dial->setObjectName("UservoiceCutoffOffset3Dial");

        gridLayout44->addWidget(UservoiceCutoffOffset3Dial, 2, 2, 1, 1);

        UservoiceCutoffOffset4Dial = new qxgeditDial(UservoiceCutoffScaleBox);
        UservoiceCutoffOffset4Dial->setObjectName("UservoiceCutoffOffset4Dial");

        gridLayout44->addWidget(UservoiceCutoffOffset4Dial, 2, 3, 1, 1);


        gridLayout43->addWidget(UservoiceCutoffScaleBox, 0, 0, 1, 4);

        UservoiceFilterFreqBox = new QGroupBox(UservoiceCutoffPage);
        UservoiceFilterFreqBox->setObjectName("UservoiceFilterFreqBox");
        gridLayout45 = new QGridLayout(UservoiceFilterFreqBox);
        gridLayout45->setSpacing(4);
        gridLayout45->setContentsMargins(4, 4, 4, 4);
        gridLayout45->setObjectName("gridLayout45");
        UservoiceFilter = new qxgeditFilter(UservoiceFilterFreqBox);
        UservoiceFilter->setObjectName("UservoiceFilter");

        gridLayout45->addWidget(UservoiceFilter, 0, 0, 1, 4);

        UservoiceCutoffDial = new qxgeditDial(UservoiceFilterFreqBox);
        UservoiceCutoffDial->setObjectName("UservoiceCutoffDial");

        gridLayout45->addWidget(UservoiceCutoffDial, 1, 0, 1, 1);

        UservoiceResonanceDial = new qxgeditDial(UservoiceFilterFreqBox);
        UservoiceResonanceDial->setObjectName("UservoiceResonanceDial");

        gridLayout45->addWidget(UservoiceResonanceDial, 1, 1, 1, 1);

        spacerItem27 = new QSpacerItem(60, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout45->addItem(spacerItem27, 1, 2, 1, 2);

        spacerItem28 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout45->addItem(spacerItem28, 2, 0, 1, 4);


        gridLayout43->addWidget(UservoiceFilterFreqBox, 0, 4, 1, 4);

        spacerItem29 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout43->addItem(spacerItem29, 1, 0, 1, 8);

        UservoiceToolBox->addTab(UservoiceCutoffPage, QString());
        UservoiceFilterEgPage = new QWidget();
        UservoiceFilterEgPage->setObjectName("UservoiceFilterEgPage");
        gridLayout46 = new QGridLayout(UservoiceFilterEgPage);
        gridLayout46->setSpacing(4);
        gridLayout46->setContentsMargins(4, 4, 4, 4);
        gridLayout46->setObjectName("gridLayout46");
        UservoiceFilterEgBox = new QGroupBox(UservoiceFilterEgPage);
        UservoiceFilterEgBox->setObjectName("UservoiceFilterEgBox");
        gridLayout47 = new QGridLayout(UservoiceFilterEgBox);
        gridLayout47->setSpacing(4);
        gridLayout47->setContentsMargins(4, 4, 4, 4);
        gridLayout47->setObjectName("gridLayout47");
        UservoiceFilterEg = new qxgeditUserEg(UservoiceFilterEgBox);
        UservoiceFilterEg->setObjectName("UservoiceFilterEg");

        gridLayout47->addWidget(UservoiceFilterEg, 0, 0, 1, 5);

        UservoiceFEGLevel0Dial = new qxgeditDial(UservoiceFilterEgBox);
        UservoiceFEGLevel0Dial->setObjectName("UservoiceFEGLevel0Dial");

        gridLayout47->addWidget(UservoiceFEGLevel0Dial, 1, 0, 1, 1);

        UservoiceFEGLevel1Dial = new qxgeditDial(UservoiceFilterEgBox);
        UservoiceFEGLevel1Dial->setObjectName("UservoiceFEGLevel1Dial");

        gridLayout47->addWidget(UservoiceFEGLevel1Dial, 1, 1, 1, 1);

        UservoiceFEGLevel2Dial = new qxgeditDial(UservoiceFilterEgBox);
        UservoiceFEGLevel2Dial->setObjectName("UservoiceFEGLevel2Dial");

        gridLayout47->addWidget(UservoiceFEGLevel2Dial, 1, 2, 1, 1);

        UservoiceFEGLevel3Dial = new qxgeditDial(UservoiceFilterEgBox);
        UservoiceFEGLevel3Dial->setObjectName("UservoiceFEGLevel3Dial");

        gridLayout47->addWidget(UservoiceFEGLevel3Dial, 1, 3, 1, 1);

        UservoiceFEGLevel4Dial = new qxgeditDial(UservoiceFilterEgBox);
        UservoiceFEGLevel4Dial->setObjectName("UservoiceFEGLevel4Dial");

        gridLayout47->addWidget(UservoiceFEGLevel4Dial, 1, 4, 1, 1);

        UservoiceFEGCenterDial = new qxgeditDial(UservoiceFilterEgBox);
        UservoiceFEGCenterDial->setObjectName("UservoiceFEGCenterDial");

        gridLayout47->addWidget(UservoiceFEGCenterDial, 2, 0, 1, 1);

        UservoiceFEGRate1Dial = new qxgeditDial(UservoiceFilterEgBox);
        UservoiceFEGRate1Dial->setObjectName("UservoiceFEGRate1Dial");

        gridLayout47->addWidget(UservoiceFEGRate1Dial, 2, 1, 1, 1);

        UservoiceFEGRate2Dial = new qxgeditDial(UservoiceFilterEgBox);
        UservoiceFEGRate2Dial->setObjectName("UservoiceFEGRate2Dial");

        gridLayout47->addWidget(UservoiceFEGRate2Dial, 2, 2, 1, 1);

        UservoiceFEGRate3Dial = new qxgeditDial(UservoiceFilterEgBox);
        UservoiceFEGRate3Dial->setObjectName("UservoiceFEGRate3Dial");

        gridLayout47->addWidget(UservoiceFEGRate3Dial, 2, 3, 1, 1);

        UservoiceFEGRate4Dial = new qxgeditDial(UservoiceFilterEgBox);
        UservoiceFEGRate4Dial->setObjectName("UservoiceFEGRate4Dial");

        gridLayout47->addWidget(UservoiceFEGRate4Dial, 2, 4, 1, 1);


        gridLayout46->addWidget(UservoiceFilterEgBox, 0, 0, 1, 5);

        UservoiceFilterEgParamBox = new QGroupBox(UservoiceFilterEgPage);
        UservoiceFilterEgParamBox->setObjectName("UservoiceFilterEgParamBox");
        gridLayout48 = new QGridLayout(UservoiceFilterEgParamBox);
        gridLayout48->setSpacing(4);
        gridLayout48->setContentsMargins(4, 4, 4, 4);
        gridLayout48->setObjectName("gridLayout48");
        UservoiceVelocityDial = new qxgeditDial(UservoiceFilterEgParamBox);
        UservoiceVelocityDial->setObjectName("UservoiceVelocityDial");

        gridLayout48->addWidget(UservoiceVelocityDial, 0, 0, 1, 1);

        UservoiceFEGVelLevelDial = new qxgeditDial(UservoiceFilterEgParamBox);
        UservoiceFEGVelLevelDial->setObjectName("UservoiceFEGVelLevelDial");

        gridLayout48->addWidget(UservoiceFEGVelLevelDial, 0, 1, 1, 1);

        UservoiceFEGVelRateDial = new qxgeditDial(UservoiceFilterEgParamBox);
        UservoiceFEGVelRateDial->setObjectName("UservoiceFEGVelRateDial");

        gridLayout48->addWidget(UservoiceFEGVelRateDial, 0, 2, 1, 1);

        UservoiceFEGScalingDial = new qxgeditDial(UservoiceFilterEgParamBox);
        UservoiceFEGScalingDial->setObjectName("UservoiceFEGScalingDial");

        gridLayout48->addWidget(UservoiceFEGScalingDial, 0, 3, 1, 1);

        spacerItem30 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout48->addItem(spacerItem30, 1, 0, 1, 4);


        gridLayout46->addWidget(UservoiceFilterEgParamBox, 0, 5, 1, 4);

        spacerItem31 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout46->addItem(spacerItem31, 1, 0, 1, 9);

        UservoiceToolBox->addTab(UservoiceFilterEgPage, QString());
        UservoicePitchEgPage = new QWidget();
        UservoicePitchEgPage->setObjectName("UservoicePitchEgPage");
        gridLayout49 = new QGridLayout(UservoicePitchEgPage);
        gridLayout49->setSpacing(4);
        gridLayout49->setContentsMargins(4, 4, 4, 4);
        gridLayout49->setObjectName("gridLayout49");
        UservoicePitchEgBox = new QGroupBox(UservoicePitchEgPage);
        UservoicePitchEgBox->setObjectName("UservoicePitchEgBox");
        gridLayout50 = new QGridLayout(UservoicePitchEgBox);
        gridLayout50->setSpacing(4);
        gridLayout50->setContentsMargins(4, 4, 4, 4);
        gridLayout50->setObjectName("gridLayout50");
        UservoicePitchEg = new qxgeditUserEg(UservoicePitchEgBox);
        UservoicePitchEg->setObjectName("UservoicePitchEg");

        gridLayout50->addWidget(UservoicePitchEg, 0, 0, 1, 5);

        UservoicePEGLevel0Dial = new qxgeditDial(UservoicePitchEgBox);
        UservoicePEGLevel0Dial->setObjectName("UservoicePEGLevel0Dial");

        gridLayout50->addWidget(UservoicePEGLevel0Dial, 1, 0, 1, 1);

        UservoicePEGLevel1Dial = new qxgeditDial(UservoicePitchEgBox);
        UservoicePEGLevel1Dial->setObjectName("UservoicePEGLevel1Dial");

        gridLayout50->addWidget(UservoicePEGLevel1Dial, 1, 1, 1, 1);

        UservoicePEGLevel2Dial = new qxgeditDial(UservoicePitchEgBox);
        UservoicePEGLevel2Dial->setObjectName("UservoicePEGLevel2Dial");

        gridLayout50->addWidget(UservoicePEGLevel2Dial, 1, 2, 1, 1);

        UservoicePEGLevel3Dial = new qxgeditDial(UservoicePitchEgBox);
        UservoicePEGLevel3Dial->setObjectName("UservoicePEGLevel3Dial");

        gridLayout50->addWidget(UservoicePEGLevel3Dial, 1, 3, 1, 1);

        UservoicePEGLevel4Dial = new qxgeditDial(UservoicePitchEgBox);
        UservoicePEGLevel4Dial->setObjectName("UservoicePEGLevel4Dial");

        gridLayout50->addWidget(UservoicePEGLevel4Dial, 1, 4, 1, 1);

        UservoicePEGCenterDial = new qxgeditDial(UservoicePitchEgBox);
        UservoicePEGCenterDial->setObjectName("UservoicePEGCenterDial");

        gridLayout50->addWidget(UservoicePEGCenterDial, 2, 0, 1, 1);

        UservoicePEGRate1Dial = new qxgeditDial(UservoicePitchEgBox);
        UservoicePEGRate1Dial->setObjectName("UservoicePEGRate1Dial");

        gridLayout50->addWidget(UservoicePEGRate1Dial, 2, 1, 1, 1);

        UservoicePEGRate2Dial = new qxgeditDial(UservoicePitchEgBox);
        UservoicePEGRate2Dial->setObjectName("UservoicePEGRate2Dial");

        gridLayout50->addWidget(UservoicePEGRate2Dial, 2, 2, 1, 1);

        UservoicePEGRate3Dial = new qxgeditDial(UservoicePitchEgBox);
        UservoicePEGRate3Dial->setObjectName("UservoicePEGRate3Dial");

        gridLayout50->addWidget(UservoicePEGRate3Dial, 2, 3, 1, 1);

        UservoicePEGRate4Dial = new qxgeditDial(UservoicePitchEgBox);
        UservoicePEGRate4Dial->setObjectName("UservoicePEGRate4Dial");

        gridLayout50->addWidget(UservoicePEGRate4Dial, 2, 4, 1, 1);


        gridLayout49->addWidget(UservoicePitchEgBox, 0, 0, 1, 5);

        UservoicePitchParamBox = new QGroupBox(UservoicePitchEgPage);
        UservoicePitchParamBox->setObjectName("UservoicePitchParamBox");
        gridLayout51 = new QGridLayout(UservoicePitchParamBox);
        gridLayout51->setSpacing(4);
        gridLayout51->setContentsMargins(4, 4, 4, 4);
        gridLayout51->setObjectName("gridLayout51");
        UservoiceNoteShiftDial = new qxgeditDial(UservoicePitchParamBox);
        UservoiceNoteShiftDial->setObjectName("UservoiceNoteShiftDial");

        gridLayout51->addWidget(UservoiceNoteShiftDial, 0, 0, 1, 1);

        UservoiceDetuneDial = new qxgeditDial(UservoicePitchParamBox);
        UservoiceDetuneDial->setObjectName("UservoiceDetuneDial");

        gridLayout51->addWidget(UservoiceDetuneDial, 0, 1, 1, 1);

        UservoicePitchScalingDial = new qxgeditDial(UservoicePitchParamBox);
        UservoicePitchScalingDial->setObjectName("UservoicePitchScalingDial");

        gridLayout51->addWidget(UservoicePitchScalingDial, 0, 2, 1, 1);

        UservoicePitchCenterDial = new qxgeditDial(UservoicePitchParamBox);
        UservoicePitchCenterDial->setObjectName("UservoicePitchCenterDial");

        gridLayout51->addWidget(UservoicePitchCenterDial, 0, 3, 1, 1);

        UservoicePEGDepthDial = new qxgeditDial(UservoicePitchParamBox);
        UservoicePEGDepthDial->setObjectName("UservoicePEGDepthDial");

        gridLayout51->addWidget(UservoicePEGDepthDial, 1, 0, 1, 1);

        UservoicePEGVelLevelDial = new qxgeditDial(UservoicePitchParamBox);
        UservoicePEGVelLevelDial->setObjectName("UservoicePEGVelLevelDial");

        gridLayout51->addWidget(UservoicePEGVelLevelDial, 1, 1, 1, 1);

        UservoicePEGVelRateDial = new qxgeditDial(UservoicePitchParamBox);
        UservoicePEGVelRateDial->setObjectName("UservoicePEGVelRateDial");

        gridLayout51->addWidget(UservoicePEGVelRateDial, 1, 2, 1, 1);

        UservoicePEGScalingDial = new qxgeditDial(UservoicePitchParamBox);
        UservoicePEGScalingDial->setObjectName("UservoicePEGScalingDial");

        gridLayout51->addWidget(UservoicePEGScalingDial, 1, 3, 1, 1);

        spacerItem32 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout51->addItem(spacerItem32, 2, 0, 1, 4);


        gridLayout49->addWidget(UservoicePitchParamBox, 0, 5, 1, 4);

        spacerItem33 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout49->addItem(spacerItem33, 1, 0, 1, 9);

        UservoiceToolBox->addTab(UservoicePitchEgPage, QString());
        UservoiceAmpEgPage = new QWidget();
        UservoiceAmpEgPage->setObjectName("UservoiceAmpEgPage");
        gridLayout52 = new QGridLayout(UservoiceAmpEgPage);
        gridLayout52->setSpacing(4);
        gridLayout52->setContentsMargins(4, 4, 4, 4);
        gridLayout52->setObjectName("gridLayout52");
        UservoiceAmpEgBox = new QGroupBox(UservoiceAmpEgPage);
        UservoiceAmpEgBox->setObjectName("UservoiceAmpEgBox");
        gridLayout53 = new QGridLayout(UservoiceAmpEgBox);
        gridLayout53->setSpacing(4);
        gridLayout53->setContentsMargins(4, 4, 4, 4);
        gridLayout53->setObjectName("gridLayout53");
        UservoiceAmpEg = new qxgeditAmpEg(UservoiceAmpEgBox);
        UservoiceAmpEg->setObjectName("UservoiceAmpEg");

        gridLayout53->addWidget(UservoiceAmpEg, 0, 0, 1, 4);

        UservoiceAEGAttackDial = new qxgeditDial(UservoiceAmpEgBox);
        UservoiceAEGAttackDial->setObjectName("UservoiceAEGAttackDial");

        gridLayout53->addWidget(UservoiceAEGAttackDial, 1, 0, 1, 1);

        UservoiceAEGDecay1Dial = new qxgeditDial(UservoiceAmpEgBox);
        UservoiceAEGDecay1Dial->setObjectName("UservoiceAEGDecay1Dial");

        gridLayout53->addWidget(UservoiceAEGDecay1Dial, 1, 1, 1, 1);

        UservoiceAEGDecay2Dial = new qxgeditDial(UservoiceAmpEgBox);
        UservoiceAEGDecay2Dial->setObjectName("UservoiceAEGDecay2Dial");

        gridLayout53->addWidget(UservoiceAEGDecay2Dial, 1, 2, 1, 1);

        UservoiceAEGReleaseDial = new qxgeditDial(UservoiceAmpEgBox);
        UservoiceAEGReleaseDial->setObjectName("UservoiceAEGReleaseDial");

        gridLayout53->addWidget(UservoiceAEGReleaseDial, 1, 3, 1, 1);

        UservoiceAEGCenterDial = new qxgeditDial(UservoiceAmpEgBox);
        UservoiceAEGCenterDial->setObjectName("UservoiceAEGCenterDial");

        gridLayout53->addWidget(UservoiceAEGCenterDial, 2, 0, 1, 1);

        UservoiceAEGLevel1Dial = new qxgeditDial(UservoiceAmpEgBox);
        UservoiceAEGLevel1Dial->setObjectName("UservoiceAEGLevel1Dial");

        gridLayout53->addWidget(UservoiceAEGLevel1Dial, 2, 1, 1, 1);

        UservoiceAEGLevel2Dial = new qxgeditDial(UservoiceAmpEgBox);
        UservoiceAEGLevel2Dial->setObjectName("UservoiceAEGLevel2Dial");

        gridLayout53->addWidget(UservoiceAEGLevel2Dial, 2, 2, 1, 1);


        gridLayout52->addWidget(UservoiceAmpEgBox, 0, 0, 1, 4);

        UservoiceAmpEgParamBox = new QGroupBox(UservoiceAmpEgPage);
        UservoiceAmpEgParamBox->setObjectName("UservoiceAmpEgParamBox");
        gridLayout54 = new QGridLayout(UservoiceAmpEgParamBox);
        gridLayout54->setSpacing(4);
        gridLayout54->setContentsMargins(4, 4, 4, 4);
        gridLayout54->setObjectName("gridLayout54");
        UservoiceAEGDelayDial = new qxgeditDial(UservoiceAmpEgParamBox);
        UservoiceAEGDelayDial->setObjectName("UservoiceAEGDelayDial");

        gridLayout54->addWidget(UservoiceAEGDelayDial, 0, 0, 1, 1);

        UservoiceAEGRateDial = new qxgeditDial(UservoiceAmpEgParamBox);
        UservoiceAEGRateDial->setObjectName("UservoiceAEGRateDial");

        gridLayout54->addWidget(UservoiceAEGRateDial, 0, 1, 1, 1);

        UservoiceAEGOffsetDial = new qxgeditDial(UservoiceAmpEgParamBox);
        UservoiceAEGOffsetDial->setObjectName("UservoiceAEGOffsetDial");

        gridLayout54->addWidget(UservoiceAEGOffsetDial, 0, 2, 1, 1);

        UservoiceAEGResonanceDial = new qxgeditDial(UservoiceAmpEgParamBox);
        UservoiceAEGResonanceDial->setObjectName("UservoiceAEGResonanceDial");

        gridLayout54->addWidget(UservoiceAEGResonanceDial, 0, 3, 1, 1);

        spacerItem34 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout54->addItem(spacerItem34, 1, 0, 1, 4);


        gridLayout52->addWidget(UservoiceAmpEgParamBox, 0, 4, 1, 5);

        spacerItem35 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout52->addItem(spacerItem35, 1, 0, 1, 9);

        UservoiceToolBox->addTab(UservoiceAmpEgPage, QString());

        vboxLayout4->addWidget(UservoiceToolBox);

        MainTabWidget->addTab(UservoiceTab, QString());

        vboxLayout->addWidget(MainTabWidget);

        qxgeditMainForm->setCentralWidget(MainCentralWidget);
        ToolBar = new QToolBar(qxgeditMainForm);
        ToolBar->setObjectName("ToolBar");
        ToolBar->setOrientation(Qt::Horizontal);
        qxgeditMainForm->addToolBar(Qt::ToolBarArea::TopToolBarArea, ToolBar);
        MenuBar = new QMenuBar(qxgeditMainForm);
        MenuBar->setObjectName("MenuBar");
        MenuBar->setGeometry(QRect(0, 0, 771, 28));
        fileMenu = new QMenu(MenuBar);
        fileMenu->setObjectName("fileMenu");
        fileOpenRecentMenu = new QMenu(fileMenu);
        fileOpenRecentMenu->setObjectName("fileOpenRecentMenu");
        viewMenu = new QMenu(MenuBar);
        viewMenu->setObjectName("viewMenu");
        helpMenu = new QMenu(MenuBar);
        helpMenu->setObjectName("helpMenu");
        qxgeditMainForm->setMenuBar(MenuBar);

        ToolBar->addAction(fileNewAction);
        ToolBar->addAction(fileOpenAction);
        ToolBar->addAction(fileSaveAction);
        ToolBar->addSeparator();
        ToolBar->addAction(viewRandomizeAction);
        MenuBar->addAction(fileMenu->menuAction());
        MenuBar->addAction(viewMenu->menuAction());
        MenuBar->addSeparator();
        MenuBar->addAction(helpMenu->menuAction());
        fileMenu->addAction(fileNewAction);
        fileMenu->addSeparator();
        fileMenu->addAction(fileOpenAction);
        fileMenu->addAction(fileOpenRecentMenu->menuAction());
        fileMenu->addSeparator();
        fileMenu->addAction(fileSaveAction);
        fileMenu->addAction(fileSaveAsAction);
        fileMenu->addSeparator();
        fileMenu->addAction(fileExitAction);
        viewMenu->addAction(viewMenubarAction);
        viewMenu->addAction(viewStatusbarAction);
        viewMenu->addAction(viewToolbarAction);
        viewMenu->addSeparator();
        viewMenu->addAction(viewRandomizeAction);
        viewMenu->addSeparator();
        viewMenu->addAction(viewOptionsAction);
        helpMenu->addAction(helpAboutAction);
        helpMenu->addAction(helpAboutQtAction);

        retranslateUi(qxgeditMainForm);

        MainTabWidget->setCurrentIndex(0);
        SystemEffectToolBox->setCurrentIndex(0);
        MultipartToolBox->setCurrentIndex(0);
        UservoiceToolBox->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(qxgeditMainForm);
    } // setupUi

    void retranslateUi(QMainWindow *qxgeditMainForm)
    {
        fileNewAction->setText(QCoreApplication::translate("qxgeditMainForm", "&New", nullptr));
        fileNewAction->setIconText(QCoreApplication::translate("qxgeditMainForm", "New", nullptr));
#if QT_CONFIG(tooltip)
        fileNewAction->setToolTip(QCoreApplication::translate("qxgeditMainForm", "New session", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        fileNewAction->setStatusTip(QCoreApplication::translate("qxgeditMainForm", "New session file", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(shortcut)
        fileNewAction->setShortcut(QCoreApplication::translate("qxgeditMainForm", "Ctrl+N", nullptr));
#endif // QT_CONFIG(shortcut)
        fileOpenAction->setText(QCoreApplication::translate("qxgeditMainForm", "&Open...", nullptr));
        fileOpenAction->setIconText(QCoreApplication::translate("qxgeditMainForm", "Open", nullptr));
#if QT_CONFIG(tooltip)
        fileOpenAction->setToolTip(QCoreApplication::translate("qxgeditMainForm", "Open session", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        fileOpenAction->setStatusTip(QCoreApplication::translate("qxgeditMainForm", "Open session from file", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(shortcut)
        fileOpenAction->setShortcut(QCoreApplication::translate("qxgeditMainForm", "Ctrl+O", nullptr));
#endif // QT_CONFIG(shortcut)
        fileSaveAction->setText(QCoreApplication::translate("qxgeditMainForm", "&Save", nullptr));
        fileSaveAction->setIconText(QCoreApplication::translate("qxgeditMainForm", "Save", nullptr));
#if QT_CONFIG(tooltip)
        fileSaveAction->setToolTip(QCoreApplication::translate("qxgeditMainForm", "Save session", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        fileSaveAction->setStatusTip(QCoreApplication::translate("qxgeditMainForm", "Save session to file", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(shortcut)
        fileSaveAction->setShortcut(QCoreApplication::translate("qxgeditMainForm", "Ctrl+S", nullptr));
#endif // QT_CONFIG(shortcut)
        fileSaveAsAction->setText(QCoreApplication::translate("qxgeditMainForm", "Save &As...", nullptr));
        fileSaveAsAction->setIconText(QCoreApplication::translate("qxgeditMainForm", "Save As", nullptr));
#if QT_CONFIG(tooltip)
        fileSaveAsAction->setToolTip(QCoreApplication::translate("qxgeditMainForm", "Save as", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        fileSaveAsAction->setStatusTip(QCoreApplication::translate("qxgeditMainForm", "Save current session with another file name", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(shortcut)
        fileSaveAsAction->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
        fileExitAction->setText(QCoreApplication::translate("qxgeditMainForm", "E&xit", nullptr));
        fileExitAction->setIconText(QCoreApplication::translate("qxgeditMainForm", "Exit", nullptr));
#if QT_CONFIG(tooltip)
        fileExitAction->setToolTip(QCoreApplication::translate("qxgeditMainForm", "Exit", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        fileExitAction->setStatusTip(QCoreApplication::translate("qxgeditMainForm", "Exit this application program", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(shortcut)
        fileExitAction->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
        viewMenubarAction->setText(QCoreApplication::translate("qxgeditMainForm", "&Menubar", nullptr));
        viewMenubarAction->setIconText(QCoreApplication::translate("qxgeditMainForm", "Menubar", nullptr));
#if QT_CONFIG(tooltip)
        viewMenubarAction->setToolTip(QCoreApplication::translate("qxgeditMainForm", "Menubar", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        viewMenubarAction->setStatusTip(QCoreApplication::translate("qxgeditMainForm", "Show/hide the main program window menubar", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(shortcut)
        viewMenubarAction->setShortcut(QCoreApplication::translate("qxgeditMainForm", "Ctrl+M", nullptr));
#endif // QT_CONFIG(shortcut)
        viewStatusbarAction->setText(QCoreApplication::translate("qxgeditMainForm", "&Statusbar", nullptr));
        viewStatusbarAction->setIconText(QCoreApplication::translate("qxgeditMainForm", "Statusbar", nullptr));
#if QT_CONFIG(tooltip)
        viewStatusbarAction->setToolTip(QCoreApplication::translate("qxgeditMainForm", "Statusbar", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        viewStatusbarAction->setStatusTip(QCoreApplication::translate("qxgeditMainForm", "Show/hide the main program window statusbar", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(shortcut)
        viewStatusbarAction->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
        viewToolbarAction->setText(QCoreApplication::translate("qxgeditMainForm", "&Toolbar", nullptr));
        viewToolbarAction->setIconText(QCoreApplication::translate("qxgeditMainForm", "Toolbar", nullptr));
#if QT_CONFIG(tooltip)
        viewToolbarAction->setToolTip(QCoreApplication::translate("qxgeditMainForm", "Toolbar", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        viewToolbarAction->setStatusTip(QCoreApplication::translate("qxgeditMainForm", "Show/hide main program window file toolbar", nullptr));
#endif // QT_CONFIG(statustip)
        viewRandomizeAction->setText(QCoreApplication::translate("qxgeditMainForm", "&Randomize", nullptr));
        viewRandomizeAction->setIconText(QCoreApplication::translate("qxgeditMainForm", "Randomize", nullptr));
#if QT_CONFIG(tooltip)
        viewRandomizeAction->setToolTip(QCoreApplication::translate("qxgeditMainForm", "Randomize", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        viewRandomizeAction->setStatusTip(QCoreApplication::translate("qxgeditMainForm", "Randomize parameters", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(shortcut)
        viewRandomizeAction->setShortcut(QCoreApplication::translate("qxgeditMainForm", "Ctrl+R", nullptr));
#endif // QT_CONFIG(shortcut)
        viewOptionsAction->setText(QCoreApplication::translate("qxgeditMainForm", "&Options...", nullptr));
        viewOptionsAction->setIconText(QCoreApplication::translate("qxgeditMainForm", "Options", nullptr));
#if QT_CONFIG(tooltip)
        viewOptionsAction->setToolTip(QCoreApplication::translate("qxgeditMainForm", "Options", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        viewOptionsAction->setStatusTip(QCoreApplication::translate("qxgeditMainForm", "Change general application program options", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(shortcut)
        viewOptionsAction->setShortcut(QCoreApplication::translate("qxgeditMainForm", "F12", nullptr));
#endif // QT_CONFIG(shortcut)
        helpAboutAction->setText(QCoreApplication::translate("qxgeditMainForm", "&About...", nullptr));
        helpAboutAction->setIconText(QCoreApplication::translate("qxgeditMainForm", "About", nullptr));
#if QT_CONFIG(tooltip)
        helpAboutAction->setToolTip(QCoreApplication::translate("qxgeditMainForm", "About", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        helpAboutAction->setStatusTip(QCoreApplication::translate("qxgeditMainForm", "Show information about this application program", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(shortcut)
        helpAboutAction->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
        helpAboutQtAction->setText(QCoreApplication::translate("qxgeditMainForm", "About &Qt...", nullptr));
        helpAboutQtAction->setIconText(QCoreApplication::translate("qxgeditMainForm", "About Qt", nullptr));
#if QT_CONFIG(tooltip)
        helpAboutQtAction->setToolTip(QCoreApplication::translate("qxgeditMainForm", "About Qt", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        helpAboutQtAction->setStatusTip(QCoreApplication::translate("qxgeditMainForm", "Show information about the Qt toolkit", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(shortcut)
        helpAboutQtAction->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
        MasterResetButton->setText(QCoreApplication::translate("qxgeditMainForm", "Reset", nullptr));
#if QT_CONFIG(tooltip)
        MasterResetButton->setToolTip(QCoreApplication::translate("qxgeditMainForm", "Reset XG System", nullptr));
#endif // QT_CONFIG(tooltip)
        SystemEffectToolBox->setTabText(SystemEffectToolBox->indexOf(SYSTEMPage), QCoreApplication::translate("qxgeditMainForm", "Master", nullptr));
        ReverbResetButton->setText(QCoreApplication::translate("qxgeditMainForm", "Reset", nullptr));
#if QT_CONFIG(tooltip)
        ReverbResetButton->setToolTip(QCoreApplication::translate("qxgeditMainForm", "Reset Reverb", nullptr));
#endif // QT_CONFIG(tooltip)
        SystemEffectToolBox->setTabText(SystemEffectToolBox->indexOf(ReverbPage), QCoreApplication::translate("qxgeditMainForm", "Reverb", nullptr));
        ChorusResetButton->setText(QCoreApplication::translate("qxgeditMainForm", "Reset", nullptr));
#if QT_CONFIG(tooltip)
        ChorusResetButton->setToolTip(QCoreApplication::translate("qxgeditMainForm", "Reset Chorus", nullptr));
#endif // QT_CONFIG(tooltip)
        SystemEffectToolBox->setTabText(SystemEffectToolBox->indexOf(ChorusPage), QCoreApplication::translate("qxgeditMainForm", "Chorus", nullptr));
        VariationResetButton->setText(QCoreApplication::translate("qxgeditMainForm", "Reset", nullptr));
#if QT_CONFIG(tooltip)
        VariationResetButton->setToolTip(QCoreApplication::translate("qxgeditMainForm", "Reset Variation", nullptr));
#endif // QT_CONFIG(tooltip)
        SystemEffectToolBox->setTabText(SystemEffectToolBox->indexOf(VariationPage), QCoreApplication::translate("qxgeditMainForm", "Variation", nullptr));
        MainTabWidget->setTabText(MainTabWidget->indexOf(SystemEffectTab), QCoreApplication::translate("qxgeditMainForm", "System / Effect", nullptr));
        MultipartResetButton->setText(QCoreApplication::translate("qxgeditMainForm", "Reset", nullptr));
#if QT_CONFIG(tooltip)
        MultipartResetButton->setToolTip(QCoreApplication::translate("qxgeditMainForm", "Reset Part", nullptr));
#endif // QT_CONFIG(tooltip)
        MultipartPartBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Part", nullptr));
        MultipartVoiceBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Voice", nullptr));
        MultipartModeBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Mode", nullptr));
        MultipartControlBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Control", nullptr));
        MultipartPortamentoBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Portamento", nullptr));
        MultipartNoteBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Note", nullptr));
        MultipartVelocityBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Velocity", nullptr));
        MultipartEffectBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Effect", nullptr));
        MultipartToolBox->setTabText(MultipartToolBox->indexOf(MultipartMainPage), QCoreApplication::translate("qxgeditMainForm", "Main", nullptr));
        MultipartVibratoBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Vibrato", nullptr));
        MultipartFilterBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Filter", nullptr));
        MultipartAmpEgBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Amp EG", nullptr));
        MultipartPitchEgBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Pitch EG", nullptr));
        MultipartToolBox->setTabText(MultipartToolBox->indexOf(MultipartTonePage), QCoreApplication::translate("qxgeditMainForm", "Tone", nullptr));
        MultipartWheelBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Modulation Wheel", nullptr));
        MultipartBendBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Pitch Bend", nullptr));
        MultipartCATBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Channel After Touch (CAT)", nullptr));
        MultipartPATBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Polyphonic After Touch (PAT)", nullptr));
        MultipartTuningBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Scale Tuning", nullptr));
        MultipartToolBox->setTabText(MultipartToolBox->indexOf(MultipartControlPage), QCoreApplication::translate("qxgeditMainForm", "Control", nullptr));
        MultipartAC1Box->setTitle(QCoreApplication::translate("qxgeditMainForm", "AC1", nullptr));
        MultipartAC2Box->setTitle(QCoreApplication::translate("qxgeditMainForm", "AC2", nullptr));
        MultipartReceiveBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Receive", nullptr));
        MultipartToolBox->setTabText(MultipartToolBox->indexOf(MultipartOptionsPage), QCoreApplication::translate("qxgeditMainForm", "Options", nullptr));
        MainTabWidget->setTabText(MainTabWidget->indexOf(MultipartTab), QCoreApplication::translate("qxgeditMainForm", "Multi Part", nullptr));
        DrumsetupResetButton->setText(QCoreApplication::translate("qxgeditMainForm", "Reset", nullptr));
#if QT_CONFIG(tooltip)
        DrumsetupResetButton->setToolTip(QCoreApplication::translate("qxgeditMainForm", "Reset Drums", nullptr));
#endif // QT_CONFIG(tooltip)
        DrumsetupPitchBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Pitch", nullptr));
        DrumsetupControlBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Control", nullptr));
        DrumsetupModeBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Mode", nullptr));
        DrumsetupEffectBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Effect", nullptr));
        DrumsetupFilterBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Filter", nullptr));
        DrumsetupAmpEgBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Amp EG", nullptr));
        DrumsetupNoteBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Receive", nullptr));
        MainTabWidget->setTabText(MainTabWidget->indexOf(DrumsetupTab), QCoreApplication::translate("qxgeditMainForm", "Drum Setup", nullptr));
        UservoiceResetButton->setText(QCoreApplication::translate("qxgeditMainForm", "Reset", nullptr));
#if QT_CONFIG(tooltip)
        UservoiceResetButton->setToolTip(QCoreApplication::translate("qxgeditMainForm", "Reset User voice", nullptr));
#endif // QT_CONFIG(tooltip)
        UservoiceAutoSendCheck->setText(QCoreApplication::translate("qxgeditMainForm", "Auto", nullptr));
#if QT_CONFIG(tooltip)
        UservoiceAutoSendCheck->setToolTip(QCoreApplication::translate("qxgeditMainForm", "Auto-send SysEx (QS300) on parameter change", nullptr));
#endif // QT_CONFIG(tooltip)
        UservoiceSendButton->setText(QCoreApplication::translate("qxgeditMainForm", "Send", nullptr));
#if QT_CONFIG(tooltip)
        UservoiceSendButton->setToolTip(QCoreApplication::translate("qxgeditMainForm", "Send SysEx (QS300)", nullptr));
#endif // QT_CONFIG(tooltip)
        UservoiceCommonBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Common", nullptr));
        UservoiceElementBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Element", nullptr));
        UservoiceLFOBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "LFO", nullptr));
        UservoiceToolBox->setTabText(UservoiceToolBox->indexOf(UservoiceMainPage), QCoreApplication::translate("qxgeditMainForm", "Main", nullptr));
        UservoiceLevelScaleBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Scale", nullptr));
        UservoiceLevelParamBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Parameters", nullptr));
        UservoiceToolBox->setTabText(UservoiceToolBox->indexOf(UservoiceLevelPage), QCoreApplication::translate("qxgeditMainForm", "Level", nullptr));
        UservoiceCutoffScaleBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Scale", nullptr));
        UservoiceFilterFreqBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Frequency", nullptr));
        UservoiceToolBox->setTabText(UservoiceToolBox->indexOf(UservoiceCutoffPage), QCoreApplication::translate("qxgeditMainForm", "Cutoff", nullptr));
        UservoiceFilterEgBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "EG", nullptr));
        UservoiceFilterEgParamBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Parameters", nullptr));
        UservoiceToolBox->setTabText(UservoiceToolBox->indexOf(UservoiceFilterEgPage), QCoreApplication::translate("qxgeditMainForm", "Filter EG", nullptr));
        UservoicePitchEgBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "EG", nullptr));
        UservoicePitchParamBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Parameters", nullptr));
        UservoiceToolBox->setTabText(UservoiceToolBox->indexOf(UservoicePitchEgPage), QCoreApplication::translate("qxgeditMainForm", "Pitch EG", nullptr));
        UservoiceAmpEgBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "EG", nullptr));
        UservoiceAmpEgParamBox->setTitle(QCoreApplication::translate("qxgeditMainForm", "Parameters", nullptr));
        UservoiceToolBox->setTabText(UservoiceToolBox->indexOf(UservoiceAmpEgPage), QCoreApplication::translate("qxgeditMainForm", "Amp EG", nullptr));
        MainTabWidget->setTabText(MainTabWidget->indexOf(UservoiceTab), QCoreApplication::translate("qxgeditMainForm", "User Voice", nullptr));
        fileMenu->setTitle(QCoreApplication::translate("qxgeditMainForm", "&File", nullptr));
        fileOpenRecentMenu->setTitle(QCoreApplication::translate("qxgeditMainForm", "Open &Recent", nullptr));
        viewMenu->setTitle(QCoreApplication::translate("qxgeditMainForm", "&View", nullptr));
        helpMenu->setTitle(QCoreApplication::translate("qxgeditMainForm", "&Help", nullptr));
        (void)qxgeditMainForm;
    } // retranslateUi

};

namespace Ui {
    class qxgeditMainForm: public Ui_qxgeditMainForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QXGEDITMAINFORM_H
